@@ -1,8 +1,30 @@
+#!/usr/bin/env php
 <?php
 
+// 5 minute timeout for the cron.php run... if it runs longer, then we need to know about it!
+$_timelimit = 300;
+set_time_limit($_timelimit); 
+
+// keep track whether we have finished script execution or not
+$_inprogress = TRUE;
+register_shutdown_function('clean_shutdown_cron');
+
+function clean_shutdown_cron(){
+	global $_inprogress;
+	global $_timelimit;
+	if ($_inprogress){
+		echo "WARNING: cron.php execution took longer than $_timelimit seconds\n";
+		printEndTime ();
+	}
+}
+
+
 $script_start_time = time();
-$start_stamps = mktime();
+$start_stamps = gmmktime(date("H"), date("i"), date("s"), date("m"), date("d"), date("Y"));
 $panel_type="cronjob";
+
+chdir(dirname(__FILE__));
+
 require("../shared/autoSQLconfig.php"); // Our main configuration file
 require_once("$dtcshared_path/dtc_lib.php");
 
@@ -63,6 +85,10 @@ function getCronFlags () {
 }
 
 function checkLockFlag () {
+	global $cronjob_table_content;
+	global $pro_mysql_cronjob_table;
+
+	$cronjob_table_content = getCronFlags();
 	// Lock the cron flag, in case the cron script takes more than 10 minutes
 	if($cronjob_table_content["lock_flag"] != "finished"){
 		echo "DB flag says that last cron job is not finished: exiting.\n
@@ -75,6 +101,12 @@ mysql -uroot -Ddtc -p --execute=\"UPDATE $pro_mysql_cronjob_table SET lock_flag=
 	$result = mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
 }
 
+function resetLockFlag () {
+	global $pro_mysql_cronjob_table;
+	$query = "UPDATE $pro_mysql_cronjob_table SET lock_flag='finished' WHERE 1;";
+	$result = mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
+}
+
 // This function call the apropriate server to tell that this server may have
 // some change in his domain list
 function commitTriggerToRemote($a){
@@ -96,14 +128,14 @@ function commitTriggerToRemoteInternal($a, $recipients){
 	}
         while($retry < 3 && $flag == false){
 		$a_vers = explode(".",phpversion());
-		if(strncmp("https://",$a["server_addr"],strlen("https://")) == 0 && $a_vers[0] <= 4 && $a_vers[1] < 3){
+		
+		if($a_vers[0] <= 4 && $a_vers[1] < 3){
 			echo "using lynx -source...";
 			$result = exec("lynx -source \"$url\"",$lines,$return_val);
 		}else{
-			echo "using file()...";
-			$lines = file ($url);
+			$httprequest = new HTTPRequest("$url");
+			$lines = $httprequest->DownloadToStringArray();
 		}
-		$nline = sizeof($lines);
 		if ($recipients == 1){
 			if(strstr($lines[0],"Successfuly recieved trigger for MX!") != false){
 				$flag = true;
@@ -232,13 +264,17 @@ function updateAllListWebArchive(){
 }
 function restartApache () {
 	global $conf_generated_file_path;
+	global $conf_dtc_system_username;
+	global $conf_dtc_system_groupname;
 
 	$APACHECTL = searchApachectl();
 	$plop = array();
 	// Now this echo is in the script itself!
 	system("chmod +x \"$conf_generated_file_path/vhost_check_dir\"");
+	system("chown $conf_dtc_system_username \"$conf_generated_file_path/vhost_check_dir\"");
 	system("$conf_generated_file_path/vhost_check_dir");
 	echo "Checking SSL certificates...";
+	system("chown $conf_dtc_system_username \"$conf_generated_file_path/vhost_check_ssl_cert\"");
 	$return_string = exec("$conf_generated_file_path/vhost_check_ssl_cert",$output,$return_val);
 	if($return_val == 0){
 		echo "ok!\n";
@@ -248,7 +284,7 @@ function restartApache () {
 		return;
         }
 	echo "Testing apache conf\n";
-	exec ("$APACHECTL configtest", $plop, $return_var);
+	exec ("$APACHECTL configtest 2>&1 | grep -qF 'Syntax OK'", $plop, $return_var);
 	if($return_var == false){
 		echo "Config is OK : restarting Apache\n";
 		echo "$APACHECTL stop\n";
@@ -314,7 +350,8 @@ function checkPop3dStarted () {
 function checkTimeAndLaunchNetBackupScript () {
 	global $start_stamps;
 	global $conf_ftp_backup_activate;
-	global $conf_ftp_backup_activate;
+	global $conf_ftp_backup_frequency;
+	global $conf_generated_file_path;
 	if(($start_stamps%(60*60*24))< 60*10 && $conf_ftp_backup_activate == "yes"){	// If 00:00 and check the frequency of the bacup and launch it if needed
 		$do_ftp_backup = "no";
 		switch($conf_ftp_backup_frequency){
@@ -333,7 +370,7 @@ function checkTimeAndLaunchNetBackupScript () {
 			break;
 		default:
 			break;
-			}
+                }
 		if($do_ftp_backup == "yes"){
 			echo "Launching ftp backup script !\n";
 			system("$conf_generated_file_path/net_backup.sh &");
@@ -344,6 +381,9 @@ function checkTimeAndLaunchNetBackupScript () {
 function cronMailSystem () {
 	global $keep_mail_generate_flag;
 	global $conf_mta_type;
+	global $conf_dtc_system_username;
+	global $conf_generated_file_path;
+	global $conf_unix_type;
 
 	$cronjob_table_content = getCronFlags();
 	if($cronjob_table_content["gen_qmail"] == "yes"){
@@ -352,12 +392,37 @@ function cronMailSystem () {
 		if($keep_mail_generate_flag == "no"){
 			markCronflagOk ("gen_qmail='no'");
 		}
+		if( file_exists($conf_generated_file_path."/postfix_virtual_mailbox_domains") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_virtual_mailbox_domains");
+		}
+		if( file_exists($conf_generated_file_path."/local_domains") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/local_domains");
+		}
+		if( file_exists($conf_generated_file_path."/postfix_virtual") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_virtual");
+		}
+		if( file_exists($conf_generated_file_path."/postfix_aliases") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_aliases");
+		}
+		if( file_exists($conf_generated_file_path."/postfix_vmailbox") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_vmailbox");
+		}
+		if( file_exists($conf_generated_file_path."/postfix_virtual_uid_mapping") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_virtual_uid_mapping");
+		}
+		if( file_exists($conf_generated_file_path."/postfix_relay_domains") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_relay_domains");
+		}
+		if( file_exists($conf_generated_file_path."/postfix_relay_recipients") ){
+			system("chown $conf_dtc_system_username $conf_generated_file_path/postfix_relay_recipients");
+		}
 	}
 	if($cronjob_table_content["qmail_newu"] == "yes"){
 		echo "Starting qmail-newu\n";
 		switch($conf_mta_type){
 		case "qmail":
-			system("/var/qmail/bin/qmail-newu");
+			//system("/var/qmail/bin/qmail-newu");
+			system("$conf_qmail_newu_path");
 			break;
 		case "postfix":
 			//not sure what newu equiv in postfix
@@ -373,15 +438,49 @@ function cronMailSystem () {
 				$PATH_POSTFIX_SCRIPT = "/etc/init.d/postfix";
 			}else if( file_exists("/usr/local/etc/rc.d/postfix")){
 				$PATH_POSTFIX_SCRIPT = "/usr/local/etc/rc.d/postfix";
+			}else if( file_exists("/etc/rc.d/rc.postfix")){
+				$PATH_POSTFIX_SCRIPT = "/etc/rc.d/rc.postfix";
+			}
+			if($conf_unix_type == "gentoo" && file_exists("/etc/init.d/postfix")) {
+				$PATH_POSTFIX_SCRIPT = "/usr/sbin/postfix";
 			}
 			system("$PATH_POSTFIX_SCRIPT reload");
+
+			$PATH_POSTSUPER = "/usr/sbin/postsuper";
+                        if( file_exists("/usr/sbin/postsuper")){
+                                $PATH_POSTSUPER = "/usr/sbin/postsuper";
+                        }else if( file_exists("/usr/local/sbin/postsuper")){
+                                $PATH_POSTSUPER = "/usr/local/sbin/postsuper";
+                        }else if( file_exists("/usr/bin/postsuper")){
+                                $PATH_POSTSUPER = "/usr/bin/postsuper";
+                        }
+
+                        // first stop queue processing in postfix
+                        echo "Stopping postfix queue...\n";
+                        system("$PATH_POSTSUPER -h ALL");
+
 			echo "Reloading amavis\n";
 			if( file_exists ("/etc/init.d/amavis") ){
 				system("/etc/init.d/amavis force-reload");
 			}else if( file_exists ("/etc/init.d/amavisd") ){
 				// Seems a restart is best (gentoo needs it)
 				system("/etc/init.d/amavisd restart");
+			// This one seems ok for slackware
+			}else if(file_exists("/etc/rc.d/rc.amavisd")){
+				system("/etc/rc.d/rc.amavisd restart");
 			}
+
+			if( file_exists ("/etc/init.d/dkimproxy") ){
+				echo "Reloading dkfilter to reload it's domains...\n";
+				system("/etc/init.d/dkimproxy force-reload");
+			}
+			
+			echo "Starting postfix queue...\n";
+                        system("$PATH_POSTSUPER -H ALL");
+
+			echo "Flushing the queue now, to make sure we have some mail delivery happening after amavisd restart...\n";
+                        system("$PATH_POSTFIX_SCRIPT flush");
+
 			break;
 		case "qmail":
 		default:
@@ -417,9 +516,9 @@ function checkNamedCronService () {
 		echo "Generating Named zonefile\n";
 		named_generate();
 		system("chgrp $conf_dtc_system_groupname $conf_generated_file_path/named.conf $conf_generated_file_path/named.slavezones.conf");
-		system("chmod 660 $conf_generated_file_path/named.conf $conf_generated_file_path/named.slavezones.conf");
+		system("chmod 770 $conf_generated_file_path/named.conf $conf_generated_file_path/named.slavezones.conf");
 		system("chgrp -R $conf_dtc_system_groupname \"$conf_generated_file_path/zones\"");
-		system("chmod 660 \"$conf_generated_file_path/zones\"");
+		system("chmod 770 \"$conf_generated_file_path/zones\"");
 		system("./checkbind.sh $conf_generated_file_path");
 		if($keep_dns_generate_flag == "no"){
 			markCronflagOk ("gen_named='no'");
@@ -427,7 +526,11 @@ function checkNamedCronService () {
 	}
 	if($cronjob_table_content["reload_named"] == "yes"){
 		echo "Reloading name-server\n";
-		system("killall -HUP named");
+		if(file_exists("/usr/sbin/rndc")){
+			system("/usr/sbin/rndc reload");
+		}else{
+			system("killall -HUP named");
+		}
 		if($keep_dns_generate_flag == "no"){
 			markCronflagOk ("reload_named='no'");
 		}
@@ -486,7 +589,7 @@ function printEndTime () {
 
 
 // Edit the following if you want to disable some services...
-
+checkLockFlag();
 checkOtherServerTriggers();
 checkNamedCronService();
 cronMailSystem();
@@ -513,7 +616,12 @@ if(($start_stamps%(60*60))< 60*10){	updateAllListWebArchive();	}
 checkWebalizerCronService();
 $cronjob_table_content = getCronFlags();
 checkTimeAndLaunchNetBackupScript();
+resetLockFlag();
+// Echo the console:
+echo("Report for this job:\n");
+echo( str_replace("<br>","\n",$console));
 printEndTime();
+$_inprogress = FALSE;
 exit();
 
 ?>
