@@ -1,5 +1,20 @@
 <?php
-
+/**
+ * Don't remove this comment for control version
+ * @package DTC
+ * @copyright LGPL
+ * @version $Id: gen_named_files.php,v 1.59 2007/06/22 19:46:23 seeb Exp $
+ * $Log: gen_named_files.php,v $
+ * Revision 1.59  2007/06/22 19:46:23  seeb
+ * w3_alias support for domain
+ *
+ * Revision 1.58  2007/06/20 19:29:07  thomas
+ * Hop!
+ *
+ * Revision 1.57  2007/06/15 21:39:10  seeb
+ * add head to file
+ *
+ **/
 function get_remote_ns($a){
 	global $console;
 	global $keep_dns_generate_flag;
@@ -10,7 +25,7 @@ function get_remote_ns($a){
 	$url = $a["server_addr"].'/dtc/list_domains.php?action=list_dns&login='.$a["server_login"].'&pass='.$a["server_pass"];
 	while($retry < 3 && $flag == false){
 		$a_vers = explode(".",phpversion());
-		if(strncmp("https://",$a["server_addr"],strlen("https://")) == 0 && $a_vers[0] <= 4 && $a_vers[1] < 3){
+		if($a_vers[0] <= 4 && $a_vers[1] < 3){
 			if( $panel_type == "cronjob"){
 				echo "\nUsing lynx -source on ".$a["server_addr"]." with login ".$a["server_login"].".\n";
 			}else{
@@ -19,11 +34,12 @@ function get_remote_ns($a){
 			$result = exec("lynx -source \"$url\"",$lines,$return_val);
 		}else{
 			if( $panel_type == "cronjob"){
-				echo "\nUsing php internal file() function on ".$a["server_addr"]." with login ".$a["server_login"].".";
+				echo "\nUsing php HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"].".";
 			}else{
-				$console .= "<br>Using php internal file() function on ".$a["server_addr"]." with login ".$a["server_login"].".";
+				$console .= "<br>Using php HTTPRequest class on ".$a["server_addr"]." with login ".$a["server_login"].".";
 			}
-			$lines = file ($url);
+			$httprequest = new HTTPRequest("$url");
+			$lines = $httprequest->DownloadToStringArray();
 		}
 		$nline = sizeof($lines);
 
@@ -183,7 +199,10 @@ function named_generate(){
 	global $conf_named_slavefile_path;
 	global $conf_named_slavezonefiles_path;
 	global $conf_ip_allowed_dns_transfer;
-
+	global $conf_domainkey_publickey_filepath;
+	global $conf_dtc_system_username;
+	global $conf_dtc_system_groupname;
+	global $conf_autogen_default_subdomains;
 	$slave_file = "";
 	$todays_serial = date("YmdH");
 
@@ -370,6 +389,24 @@ $more_mx_server
 @	IN	TXT	\"$root_txt_record2\"
 	IN	A	$ip_to_write
 ";
+			// if we have the public.key for DomainKeys, write it into our zone file
+			if (file_exists($conf_domainkey_publickey_filepath)){
+				$key_file_array = file($conf_domainkey_publickey_filepath, FILE_IGNORE_NEW_LINES);
+				// skip the first and last lines (the ---PUBLIC---)
+				$KEY = "";
+				for ($key_file_array_count = 1; $key_file_array_count < count($key_file_array) - 1; $key_file_array_count++){
+					$KEY .= $key_file_array[$key_file_array_count];
+				}
+				// This line is added for php4 support:
+				$KEY = str_replace("\n","",$KEY);
+				$SELECTOR="postfix";
+				$DOMAIN=$web_name;
+				$NSRECORD="$SELECTOR._domainkey IN TXT \"k=rsa;p=$KEY; t=y\"";
+				$NSRECORDDEFAULT="_domainkey IN TXT \"o=~\"";
+				$this_site_file .= "$NSRECORDDEFAULT\n";
+				$this_site_file .= "$NSRECORD\n";
+			}
+
 			// Add all subdomains to it !
 			$is_pop_subdomain_set = "no";
 			$is_imap_subdomain_set = "no";
@@ -400,7 +437,21 @@ $more_mx_server
 				}else{
 					$the_ip_writed = "CNAME\t".$subdomain["ip"].".";
 				}
-
+// Note from Thomas Goirand:
+// This patch seems to 1/ produce some NOTICE like this:
+// Notice: Undefined variable: seeb_alias in /usr/share/dtc/admin/genfiles/gen_named_files.php on line 442
+// Notice: Undefined variable: seeb_alias in /usr/share/dtc/admin/genfiles/gen_named_files.php on line 441
+// as $seeb_alias is never defined anywhere!!!
+// and 2/ make the stuff unreachable. So I'm commenting out, sorry. Seeb: if you see this, patch this file
+// so it always work, thanks!
+//
+// patch by seeb w3_alias
+//if ($subdomain['w3_alias'] =="yes" && $subdomain['subdomain_name']!="www"){
+//             $sub_alias="www.".$subdomain['subdomain_name'];
+//  $console.="Generated w3alias: ".$seeb_alias.".".$subdomain['domain_name']."<br/>";
+//     $this_site_file .= "$seeb_alias\tIN\tCNAME      ".$subdomain['subdomain_name'].".".$subdomain['domain_name'].".\n";
+//}				
+// end of patch 3w_alias				
 				if($web_subname == "pop"){
 					$is_pop_subdomain_set = "yes";
 				}
@@ -419,12 +470,18 @@ $more_mx_server
 				if($web_subname == "list"){
 					$is_list_subdomain_set = "yes";
 				}
-				// write TTL values into subdomain
-				if ($conf_use_cname_for_subdomains == "yes"){
-					$this_site_file .= "$web_subname	$sub_ttl	IN	CNAME	@\n";
+				// if we have a srv_record here (ie a port, then we don't write the normal subdomain entry, just the SRV record
+			 	if (isset($subdomain["srv_record"]) && $subdomain["srv_record"] != "")
+				{
+					$this_site_file .= "$web_subname	$sub_ttl	SRV	0	10	".$subdomain["srv_record"]."	".$subdomain["ip"]."\n";
+				} else {	
+					// write TTL values into subdomain
+					if ($conf_use_cname_for_subdomains == "yes"){
+						$this_site_file .= "$web_subname	$sub_ttl	IN	CNAME	@\n";
 
-				}else{
-					$this_site_file .= "$web_subname	$sub_ttl	IN	$the_ip_writed\n";
+					}else{
+						$this_site_file .= "$web_subname	$sub_ttl	IN	$the_ip_writed\n";
+					}
 				}
 				if($subdomain["associated_txt_record"] != "" && (isIP($subdomain["ip"]) || $subdomain["ip"] == "default")){
 					$this_site_file .= "$web_subname	IN	TXT	\"".$subdomain["associated_txt_record"]."\"\n";
@@ -435,36 +492,38 @@ $more_mx_server
 					$this_site_file .= "$nameserver_for	IN	NS	$web_subname.$web_name.\n";
 				}
 			}
-			if( $is_pop_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
-				$this_site_file .= "pop	IN	A	$ip_to_write\n";
-			} else if ( $is_pop_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
-				$this_site_file .= "pop IN	CNAME	@\n";
+			if( $conf_autogen_default_subdomains == "yes" ){
+				if( $is_pop_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
+					$this_site_file .= "pop	IN	A	$ip_to_write\n";
+				} else if ( $is_pop_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
+					$this_site_file .= "pop IN	CNAME	@\n";
+				}
+				if( $is_imap_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
+					$this_site_file .= "imap	IN	A	$ip_to_write\n";
+				} else if ( $is_imap_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
+                        	        $this_site_file .= "imap	IN	CNAME	@\n";
+				}
+				if( $is_mail_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
+					$this_site_file .= "mail	IN	A	$ip_to_write\n";
+				} else if ( $is_mail_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
+                        	        $this_site_file .= "mail        IN      CNAME	@\n";
+				}
+				if( $is_smtp_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
+					$this_site_file .= "smtp	IN	A	$ip_to_write\n";
+				} else if ( $is_smtp_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
+					$this_site_file .= "smtp        IN      CNAME	@\n";
+				}
+				if( $is_ftp_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
+					$this_site_file .= "ftp	IN	A	$ip_to_write\n";
+				} else if ( $is_ftp_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
+					$this_site_file .= "ftp        IN      CNAME	@\n";
+				}
+				if( $is_list_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
+					$this_site_file .= "list	IN	A	$ip_to_write\n";
+				} else if ( $is_list_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
+                        	        $this_site_file .= "list        IN      CNAME	@\n";
+				}
 			}
-			if( $is_imap_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
-				$this_site_file .= "imap	IN	A	$ip_to_write\n";
-			} else if ( $is_imap_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
-                                $this_site_file .= "imap	IN	CNAME	@\n";
-			}
-			if( $is_mail_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
-				$this_site_file .= "mail	IN	A	$ip_to_write\n";
-			} else if ( $is_mail_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
-                                $this_site_file .= "mail        IN      CNAME	@\n";
-			}
-			if( $is_smtp_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
-				$this_site_file .= "smtp	IN	A	$ip_to_write\n";
-			} else if ( $is_smtp_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
-                                $this_site_file .= "smtp        IN      CNAME	@\n";
-                        }
-			if( $is_ftp_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
-				$this_site_file .= "ftp	IN	A	$ip_to_write\n";
-			} else if ( $is_ftp_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
-                                $this_site_file .= "ftp        IN      CNAME	@\n";
-                        }
-			if( $is_list_subdomain_set != "yes" && $conf_use_cname_for_subdomains != "yes"){
-				$this_site_file .= "list	IN	A	$ip_to_write\n";
-			} else if ( $is_list_subdomain_set != "yes" && $conf_use_cname_for_subdomains == "yes"){
-                                $this_site_file .= "list        IN      CNAME	@\n";
-                        }
 			if($web_serial_flag=="yes"){
 				$console .= "Updating zone file for domain $web_name using serial : $todays_serial, ipaddr : $ip_to_write<br>";
 				$filep = fopen("$conf_generated_file_path/$conf_named_zonefiles_path/$web_name", "w+");
@@ -474,6 +533,8 @@ $more_mx_server
 				}
 				fwrite($filep,$this_site_file);
 				fclose($filep);
+				chown("$conf_generated_file_path/$conf_named_zonefiles_path/$web_name",$conf_dtc_system_username);
+				chgrp("$conf_generated_file_path/$conf_named_zonefiles_path/$web_name",$conf_dtc_system_groupname);
 				$query_serial = "UPDATE $pro_mysql_domain_table SET generate_flag='no' WHERE name='$web_name' LIMIT 1;";
 				$result_serial = mysql_query ($query_serial)or die("Cannot execute query \"$query_serial\"");
 			}
