@@ -3,30 +3,30 @@
 /********************************************************
  * This will generate the appropriate files for postfix *
  * Generate the following files:              ***********
- * /usr/share/dtc/etc/postfix_virtual_mailbox_domains       *
- * domain.com	virtual                       *
- *                                            *
- * /usr/share/dtc/etc/postfix_virtual                       *
- * postmaster@domain.com	postmaster    *
- *                                            *
- * /usr/share/dtc/etc/postfix_vmailbox                      *
+ * $conf_generated_file_path/postfix_virtual_mailbox_domains
+ * domain.com	virtual
+ *
+ * $conf_generated_file_path/postfix_virtual
+ * postmaster@domain.com	postmaster
+ *
+ * $conf_generated_file_path/postfix_vmailbox
  * emailaddress@domain.com	dtc/domain/Mailboxs/<emailaddress>/Maildir/
  *                                            *
- * /usr/share/dtc/etc/postfix_virtual_uid_mapping           
+ * $conf_generated_file_path/postfix_virtual_uid_mapping           
  * emailaddress@domain.com	65534         
  *
- * /usr/share/dtc/etc/postfix_relay_domains
+ * $conf_generated_file_path/postfix_relay_domains
  * domain.name
  * domain2.name
  *
- * /usr/share/dtc/etc/postfix_relay_recipients
+ * $conf_generated_file_path/postfix_relay_recipients
  * emailaddress@domain.com	OK
  * emailaddress2@domain.com	OK
  *
- * /usr/share/dtc/etc/postfix_aliases
+ * $conf_generated_file_path/postfix_aliases
  * mailinglist:		"|/usr/bin/mlmmj-recieve"
  *
- * /usr/share/dtc/etc/recipient_lists/$domain
+ * $conf_generated_file_path/recipient_lists/$domain
  * ($conf_postfix_recipient_lists_path/$domain)
  * email@$domain	OK
  *
@@ -45,8 +45,11 @@ function mail_account_generate_postfix(){
 	global $conf_unix_type;
 
 	global $conf_nobody_user_id;
+	global $conf_dtc_system_uid;
+	global $conf_dtc_system_username;
 
 	global $conf_use_cyrus;
+	global $conf_use_mail_alias_group;
 
 	//global $conf_postfix_virtual_mailbox_domains_path;
 	//global $conf_postfix_virtual_path;
@@ -82,6 +85,11 @@ function mail_account_generate_postfix(){
 
 	$data = ""; // init var for use later on
 
+	#CL: Don create sasldb password when using cyrus. 
+	if($conf_use_cyrus != "yes")
+	{
+		genSasl2PasswdDBStart();
+	}
 	// go through each admin login and find the domains associated 
 	$query = "SELECT * FROM $pro_mysql_admin_table ORDER BY adm_login;";
 	$result = mysql_query ($query)or die("Cannot execute query : \"$query\"");
@@ -146,7 +154,46 @@ function mail_account_generate_postfix(){
 					}
 				}
 			}
-			if(isset($domain["emails"]) && $primary_mx){
+//Mail Group Aliases Start
+			if ( $conf_use_mail_alias_group == "yes" )
+			{
+				if ( $domain["domain_parking"] != "no-parking" )
+				{
+					// @domain1 -> @domain2
+					$domains_postmasters_file.= "# Mail Alias Groups for ".$domain["name"]."\n";
+					$domains_postmasters_file.= "@".$domain["name"]." @".$domain["domain_parking"]."\n";
+					$domains_postmasters_file.= "#\n";
+				}
+				elseif ( $primary_mx && isset($domain["aliases"]) )
+				{
+					// name@domain1 -> othername@domain1,user@domain2,etc.
+					$aliases = $domain["aliases"];
+					$nbr_boites = sizeof($aliases);
+					// go through each of these emails and build the vmailbox file
+					//also create our sasldb2 if we have a saslpasswd2 exe
+					for($k=0;$k<$nbr_boites;$k++){
+						$alias = $aliases[$k];
+						$id = $alias["id"];
+						$domain_parent = $alias["domain_parent"];
+						$ainc = $alias["autoinc"];
+						$mailbox_cleanup1 = str_replace("\r\n", "\n", $alias["delivery_group"]);
+						$mailbox_cleanup2 = split("\n", $mailbox_cleanup1);
+						$deliver_mailbox = '';
+						if ( $k==0 ) $domains_postmasters_file.= "# Mail Alias Groups for : ".$domain_parent."\n";
+						for($x=0;$x<count($mailbox_cleanup2);$x++)
+						{
+							if ( $x<count($mailbox_cleanup2)-1 )
+								$deliver_mailbox.=trim($mailbox_cleanup2[$x]).",";
+							else
+								$deliver_mailbox.=trim($mailbox_cleanup2[$x]);
+						}
+						$domains_postmasters_file.=$id."@".$domain_parent." ".$deliver_mailbox."\n";
+						if ( $k==$nbr_boites-1 ) $domains_postmasters_file.= "#\n";
+					}
+				}
+			}
+//Mail Group Aliases End
+			if(isset($domain["emails"]) && $primary_mx && $domain["domain_parking"] == "no-parking" ){
 				$emails = $domain["emails"];
 				$nbr_boites = sizeof($emails);
 				// go through each of these emails and build the vmailbox file
@@ -156,10 +203,9 @@ function mail_account_generate_postfix(){
 					$id = $email["id"];
 					$uid = $email["uid"];
 					// if our uid is 65534, make sure it's the correct uid as per the OS (99 for redhat)
-					if ($uid == 65534)
-					{
+/*					if ($uid == 65534){
 						$uid = $conf_nobody_user_id;	
-					}
+					}*/
 					$localdeliver = $email["localdeliver"];
 					$redirect1 = $email["redirect1"];
 					$redirect2 = $email["redirect2"];
@@ -172,10 +218,14 @@ function mail_account_generate_postfix(){
 					$vacation_flag = $email["vacation_flag"];
 					$vacation_text = stripslashes($email["vacation_text"]);
 
+					if ( $k==0 ) $domains_postmasters_file.= "# Mailboxes for : ".$domain_full_name."\n";
 					$spam_stuff_done = 0;
 					$homedir_created = 0;
+					if (!isset($home) || $home==""){
+						$console .= "Missing home variable for $id";
+					}
 					if(! is_dir($home) ){
-						system("/bin/mkdir -p $home");
+						system("/bin/mkdir -p $home && maildirmake $home");
 						$homedir_created = 1;
 					}
 
@@ -186,10 +236,18 @@ function mail_account_generate_postfix(){
 					if ($id == "postmaster"){
 						$postmaster_address++; 
 					}
+					// Previously: only generate sasl logins for local accounts
+					// In fact, there is no reason to do so. We might want to create a mail account ONLY for sending
+					// some mail, and not receiving.
+					#CL: Not needed for cyrus
+					if($conf_use_cyrus != "yes")
+					{
+						genSasl2PasswdDBEntry($domain_full_name,$id,$passwdtemp,$conf_addr_mail_server);
+					}
+					// system("./genfiles/gen_sasl.sh $domain_full_name $id $passwdtemp $conf_addr_mail_server");
+
 					// first try and see if we have postfix in a chroot, else just put it in it's default location
 					if ($localdeliver == "yes" || $localdeliver == "true"){
-						// only generate sasl logins for local accounts
-						system("./genfiles/gen_sasl.sh $domain_full_name $id $passwdtemp $conf_addr_mail_server");
 						// setup the catch_all for locally delivered email addresses
 						if ($id == $catch_all_id){
 							//$store_catch_all_md .= "@$domain_full_name        $home/Maildir/\n";
@@ -197,23 +255,24 @@ function mail_account_generate_postfix(){
 						} 
 						$vmailboxes_file .= "$id@$domain_full_name $home/Maildir/\n";
 						$uid_mappings_file .= "$id@$domain_full_name $uid\n";				
-						if (isset($catch_all_id) || $catch_all_id != "")
-						{
+						if (isset($catch_all_id) || $catch_all_id != ""){
 							//just so we can deliver to our vmailboxs if we have set a catch-all (otherwise postfix gets confused, and delivers all mail to the catch all)
 							$domains_postmasters_file .= "$id@$domain_full_name $id@$domain_full_name\n";
 						}
 					}
+
 					if(isset($redirect1) && $redirect1 != ""){
 						unset($extra_redirects);
 						if ($localdeliver == "yes" || $localdeliver == "true"){
-							//need to generate .mailfilter file with "cc" and also local delivery
-							if($conf_use_cyrus != "yes"){
-								system("./genfiles/gen_mailfilter.sh $home $id $domain_full_name $spam_mailbox_enable $spam_mailbox $vacation_flag $redirect1");
+							// need to generate .mailfilter file with "cc" and also local delivery
+							if($conf_use_cyrus != "yes" && (!isset($redirect2) || $redirect2 == "" )){
+								genDotMailfilterFile($home,$id,$domain_full_name,$spam_mailbox_enable,$spam_mailbox,$vacation_flag,$vacation_text,$redirect1);
+								/*system("./genfiles/gen_mailfilter.sh $home $id $domain_full_name $spam_mailbox_enable $spam_mailbox $vacation_flag $redirect1");
 								if($vacation_flag == "yes"){
 									$vac_fp = fopen("$home/.vacation.msg","w+");
 									fwrite($vac_fp,$vacation_text);
 									fclose($vac_fp);
-								}
+								}*/
 							}
 							$spam_stuff_done = 1;
 						} else {
@@ -223,12 +282,13 @@ function mail_account_generate_postfix(){
 							if ($localdeliver == "yes" || $localdeliver == "true"){
 								//need to generate .mailfilter file with "cc" and also local delivery
 								if($conf_use_cyrus != "yes"){
-									system("./genfiles/gen_mailfilter.sh $home $id $domain_full_name $spam_mailbox_enable $spam_mailbox $vacation_flag $redirect1 $redirect2");
+									genDotMailfilterFile($home,$id,$domain_full_name,$spam_mailbox_enable,$spam_mailbox,$vacation_flag,$vacation_text,$redirect1,$redirect2);
+									/*system("./genfiles/gen_mailfilter.sh $home $id $domain_full_name $spam_mailbox_enable $spam_mailbox $vacation_flag $redirect1 $redirect2");
 									if($vacation_flag == "yes"){
 										$vac_fp = fopen("$home/.vacation.msg","w+");
 										fwrite($vac_fp,$vacation_text);
 										fclose($vac_fp);
-									}
+									}*/
 								}
 								$spam_stuff_done = 1;
 							} else if (isset($extra_redirects)) {
@@ -247,12 +307,19 @@ function mail_account_generate_postfix(){
 					//if we haven't added the spam mailbox yet, do it here
 					if ($spam_stuff_done == 0){
 						if($conf_use_cyrus != "yes"){
-							system("./genfiles/gen_mailfilter.sh $home $id $domain_full_name $spam_mailbox_enable $spam_mailbox");
+							genDotMailfilterFile($home,$id,$domain_full_name,$spam_mailbox_enable,$spam_mailbox,$vacation_flag,$vacation_text,$redirect1,$redirect2);
+							/* system("./genfiles/gen_mailfilter.sh $home $id $domain_full_name $spam_mailbox_enable $spam_mailbox $vacation_flag");
+							if($vacation_flag == "yes"){
+								$vac_fp = fopen("$home/.vacation.msg","w+");
+								fwrite($vac_fp,$vacation_text);
+								fclose($vac_fp);
+							}*/
 						}
 					}
 					if(is_dir($home) && $homedir_created == 1){
-						system("chown -R $conf_nobody_user_id $home");
+						system("chown -R $conf_dtc_system_username $home");
 					}
+					if ( $k==$nbr_boites-1 ) $domains_postmasters_file.= "#\n";
 				}
 			}
 			//add support for creation of mailing lists
@@ -404,11 +471,11 @@ function mail_account_generate_postfix(){
 
 	//now that we have our base files, go and rebuild the db's
 	if($conf_unix_type == "bsd"){
-		$POSTMAP_BIN = "/usr/local/sbin/postmap";
-		$POSTALIAS_BIN = "/usr/local/sbin/postalias";
+		$POSTMAP_BIN = "/usr/local/sbin/postmap -r";
+		$POSTALIAS_BIN = "/usr/local/sbin/postalias -r";
 	}else{
-		$POSTMAP_BIN = "/usr/sbin/postmap";
-		$POSTALIAS_BIN = "/usr/sbin/postalias";
+		$POSTMAP_BIN = "/usr/sbin/postmap -r";
+		$POSTALIAS_BIN = "/usr/sbin/postalias -r";
 	}
 
 	system("$POSTMAP_BIN $conf_postfix_virtual_mailbox_domains_path");
@@ -417,7 +484,8 @@ function mail_account_generate_postfix(){
 	system("$POSTMAP_BIN $conf_postfix_vmailbox_path");
 	system("$POSTMAP_BIN $conf_postfix_virtual_uid_mapping_path");
 	system("$POSTMAP_BIN $conf_postfix_relay_recipients_path");
-
+	genSaslFinishConfigAndRights();
+	system("chown  ".$conf_dtc_system_username.":postfix ".$conf_generated_file_path."/postfix_*");
 	//in case our relay_domains file hasn't been created correctly, we should touch it
 	system("touch $conf_postfix_relay_domains_path");
 }
