@@ -32,7 +32,7 @@ fi
 	$chk_dir_script .= "
 if [ ! -d $dir ] ; then
 	mkdir -p $dir
-	chown $conf_dtc_system_username:$conf_dtc_system_groupname
+	chown $conf_dtc_system_username:$conf_dtc_system_groupname $dir
 	echo \"Directory $dir was missing and has been created.\"
 fi
 ";
@@ -85,8 +85,10 @@ function checkCertificate($cert_path,$common_name){
 function test_valid_local_ip($address){
 	global $console;
 	global $panel_type;
+	global $conf_nated_vhost_ip;
+
 	$port = 80;
-	
+
         if (!function_exists('socket_create')) {
 		if($panel_type=="cronjob"){
 			echo("The socket_create function does not exist or is not enabled, please ensure you have a php_sockets.so or php_sockets.dll, or have the sockets compiled into PHP.  No IP checks can be done, so assuming all IPs configured are valid.\n");
@@ -98,9 +100,11 @@ function test_valid_local_ip($address){
 	$console .= "Checking IP $address:";
 	$old_error_reporting = error_reporting('E_NONE');
 
-	if (($sock = socket_create(AF_INET, SOCK_STREAM, SOL_TCP)) < 0) {
-		echo "socket_create() failed: reason: " . socket_strerror($sock) . "\n";
-		return false;
+	if($conf_nated_vhost_ip != '*'){
+		if (($sock = socket_create(AF_INET, SOCK_STREAM, SOL_TCP)) < 0) {
+			echo "socket_create() failed: reason: " . socket_strerror($sock) . "\n";
+			return false;
+		}
 	}
 
 	if (!($ret = socket_bind($sock, $address, $port))) {
@@ -140,10 +144,23 @@ function test_valid_local_ip($address){
 	error_reporting($old_error_reporting);
 }
 
+function get_defaultCharsetDirective($db_entry){
+	if(!isset($db_entry) || $db_entry == "dtc-wont-add" || $db_entry == ""){
+		return "";
+	}else{
+		if($db_entry == "Off"){
+			return "\tAddDefaultCharset Off\n";
+		}else{
+			return "\tAddDefaultCharset ".$db_entry."\n";
+		}
+	}
+}
+
 function pro_vhost_generate(){
 	global $pro_mysql_domain_table;
 	global $pro_mysql_admin_table;
 	global $pro_mysql_subdomain_table;
+	global $pro_mysql_ssl_ips_table;
 
 	global $conf_db_version;
 	global $conf_unix_type;
@@ -161,6 +178,7 @@ function pro_vhost_generate(){
 	global $conf_php_library_path;
 	global $conf_php_additional_library_path;
 	global $conf_administrative_site;
+	global $conf_administrative_ssl_port;
 	global $conf_use_ssl;
 
 	global $conf_shared_renewal_shutdown;
@@ -175,7 +193,14 @@ function pro_vhost_generate(){
 	global $conf_main_domain;
 	global $conf_404_subdomain;
 
+	global $conf_mysql_db;
+
+	global $conf_apache_version;
+
 	$vhost_file = "";
+	$logrotate_file = "# Do not edit this file, it's generated
+# edit /etc/dtc/logrotate.template instead!
+";
 
 $vhost_file .= "# WARNING ! This file is automatically edited by the dtc cron
 # daemon: do not edit. All manual changes to hosts that are configured within
@@ -234,6 +259,10 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	{
 		$a = mysql_fetch_array($result2);
 		$path_404 = $a["path"]."/$conf_main_domain/subdomains/$conf_404_subdomain";
+		// make sure the vhost_chk_dir script has the 404 entries
+                vhost_chk_dir_sh("$path_404/html");
+                vhost_chk_dir_sh("$path_404/logs");
+                vhost_chk_dir_sh("$path_404/cgi-bin");
 	}
 
 	if($conf_use_multiple_ip == "yes" && $conf_use_nated_vhost == "no"){
@@ -252,9 +281,8 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 			$num_rows2 = mysql_num_rows($result2);
 			if($num_rows2 > 0){
 				$vhost_file .= "NameVirtualHost ".$all_site_addrs[$i].":80\n";
-				if ($enable404feature == true)
-				{
-				$vhost_file .= "<VirtualHost ".$all_site_addrs[$i].":80>
+				if ($enable404feature == true){
+					$vhost_file .= "<VirtualHost ".$all_site_addrs[$i].":80>
 	ServerName $conf_404_subdomain.$conf_main_domain
 	DocumentRoot $path_404/html
 	ScriptAlias /cgi-bin $path_404/cgi-bin
@@ -262,9 +290,10 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	LogSQLTransferLogTable ".str_replace("-","A",str_replace(".","_",$conf_main_domain)).'$'.$conf_404_subdomain.'$'."xfer
 	LogSQLScoreDomain $conf_main_domain
 	LogSQLScoreSubdomain $conf_404_subdomain
-	LogSQLScoreTable dtc.http_accounting
+	LogSQLScoreTable $conf_mysql_db.http_accounting
 	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4
 </VirtualHost>\n";
+					$logrotate_file .= "$path_404/logs/error.log ";
 				}
 			}
 		}
@@ -288,8 +317,7 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 			}
 			$vhost_file .= "NameVirtualHost ".$conf_main_site_ip.":80\n";
 		}
-		if ($enable404feature == true)
-		{
+		if ($enable404feature == true){
 			$vhost_file .= "<VirtualHost ".$ip_for_404.":80>
         ServerName $conf_404_subdomain.$conf_main_domain
         DocumentRoot $path_404/html
@@ -298,27 +326,36 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
         LogSQLTransferLogTable ".str_replace("-","A",str_replace(".","_",$conf_main_domain)).'$'.$conf_404_subdomain.'$'."xfer
         LogSQLScoreDomain $conf_main_domain
         LogSQLScoreSubdomain $conf_404_subdomain
-        LogSQLScoreTable dtc.http_accounting
+        LogSQLScoreTable $conf_mysql_db.http_accounting
         DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4
 </VirtualHost>\n";
+			$logrotate_file .= "$path_404/logs/error.log ";
 		}
 	}
 
 	$vhost_file .= "<Directory $conf_dtcadmin_path>
 	Options FollowSymLinks
+	Order Deny,Allow
+	Allow from all
 </Directory>
 <Directory $conf_dtcclient_path>
 	Options FollowSymLinks
+	Order Deny,Allow
+	Allow from all
 </Directory>
 <Directory $conf_dtcemail_path>
 	Options FollowSymLinks
+	Order Deny,Allow
+	Allow from all
 </Directory>\n";
-	if($conf_unix_type == "debian"){
-		$vhost_file .= "ScriptAlias /cgi-bin /usr/lib/cgi-bin
-<Directory /usr/lib/cgi-bin>
-	Options FollowSymLinks
-</Directory>\n";
-	}
+//	This is not needed anymore as we don't use cgi-bin for the rrdtool graphing anymore
+//	If you need it for your specific config, then add it in the main apache config
+//	if($conf_unix_type == "debian"){
+//		$vhost_file .= "ScriptAlias /cgi-bin /usr/lib/cgi-bin
+//<Directory /usr/lib/cgi-bin>
+//	Options FollowSymLinks
+//</Directory>\n";
+//	}
 
 	for($i=0;$i<$num_rows;$i++){
 		$row = mysql_fetch_array($result) or die ("Cannot fetch user");
@@ -406,6 +443,14 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 		for($j=0;$j<$num_rows2;$j++){
 			$subdomain = mysql_fetch_array($result2) or die ("Cannot fetch user");
 			$web_subname = $subdomain["subdomain_name"];
+			if( $subdomain["customize_vhost"] == ""){
+				$custom_directives = "";
+			}else{
+				$custom_directives = "
+	# Start of custom directives
+	".$subdomain["customize_vhost"]."
+	# End of custom directives";
+			}
 
 //			$console .= "Working on $web_subname.$web_name\n";
 
@@ -435,13 +480,13 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 				$log_tablename = str_replace("-","A",str_replace(".","_",$web_name)).'$'.str_replace("-","A",str_replace(".","_",$web_subname));
 				if($conf_use_ssl == "yes" && $k == 0){
 					# add the directive for SSL here
-					if (test_valid_local_ip($ip_to_write) && !ereg("Listen ".$ip_to_write.":443", $vhost_file_listen))
+					if (test_valid_local_ip($ip_to_write) && !ereg("Listen ".$ip_to_write.":".$conf_administrative_ssl_port, $vhost_file_listen))
 					{
-						$vhost_file_listen .= "Listen ".$ip_to_write.":443\n";
+						$vhost_file_listen .= "Listen ".$ip_to_write.":".$conf_administrative_ssl_port."\n";
 					} else {
-						$vhost_file_listen .= "#Listen ".$ip_to_write.":443\n";
+						$vhost_file_listen .= "#Listen ".$ip_to_write.":".$conf_administrative_ssl_port."\n";
 					}
-					$vhost_file .= "<VirtualHost ".$ip_to_write.":443>\n";
+					$vhost_file .= "<VirtualHost ".$ip_to_write.":".$conf_administrative_ssl_port.">\n";
 				} else if ($k == 1 && isset($backup_ip_addr) || ($conf_use_ssl != "yes" && $k == 0 && isset($backup_ip_addr))) {
 					$vhost_file .= "<VirtualHost ".$backup_ip_addr.":80>\n";
 				}else {
@@ -483,13 +528,13 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 							$gblx = "php_admin_value register_globals 0";
 						}
 						if($rowX["safe_mode"] == "no" && $ax["safe_mode"] == "no"){
-							$safex = "php_admin_value safe_mode 1";
-						}else{
 							$safex = "php_admin_value safe_mode 0";
+						}else{
+							$safex = "php_admin_value safe_mode 1";
 						}
 						$vhost_file .= "\tAlias /$subdomx.$web_nameX $web_pathX/$web_nameX/subdomains/$subdomx/html
 	<Location /$subdomx.$web_nameX>
-		$safex
+		".$safex.$custom_directives."
 		php_admin_value open_basedir \"$web_pathX/$web_nameX/:$conf_php_library_path:$conf_php_additional_library_path:\"
 		$gblx
 	</Location>\n";
@@ -512,7 +557,9 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	Alias /dtcemail $conf_dtcemail_path
 	Alias /dtcadmin $conf_dtcadmin_path
 	Alias /stats $web_path/$web_name/subdomains/$web_subname/logs
+	Alias /awstats-icon /usr/share/awstats/icon
 	Alias /squirrelmail ".$conf_tools_prefix."/squirrelmail
+	Alias /roundcube /var/lib/roundcube
 	php_admin_value sendmail_from webmaster@$web_name
 	DocumentRoot $web_path/$web_name/subdomains/$web_subname/html
 # No ScriptAlias: we want to use system's /usr/lib/cgi-bin !!!
@@ -521,11 +568,12 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 	LogSQLTransferLogTable $log_tablename\$xfer
 	LogSQLScoreDomain $web_name
 	LogSQLScoreSubdomain $web_subname
-	LogSQLScoreTable dtc.http_accounting
-	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4
+	LogSQLScoreTable $conf_mysql_db.http_accounting
+	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4$custom_directives
 </VirtualHost>
 
 ";
+			$logrotate_file .= "$web_path/$web_name/subdomains/$web_subname/logs/error.log ";
 } // - end of for loop
 
 // ---------------------------------------------------
@@ -534,6 +582,13 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 			} else {
 				// Generate a permanet redirect for all subdomains of target if using a domain parking
 				if($domain_parking != "no-parking"){
+					if($j == 0){
+						$console .= "Making domain parking for $web_name\n";
+						$vhost_file .= "<VirtualHost ".$ip_to_write.":80>
+	ServerName $web_name
+	Redirect permanent / http://$domain_parking/
+</VirtualHost>\n\n";
+					}
 					$console .= "Making domain parking for $web_subname.$web_name\n";
 					$vhost_file .= "<VirtualHost ".$ip_to_write.":80>
 	ServerName $web_subname.$web_name
@@ -550,6 +605,26 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 						$ssl_returns = checkCertificate($ssl_cert_folder_path,$web_subname.".".$web_name);
 						if($ssl_returns == "yes"){
 							$iteration_table[] = "ssl";
+							// Start of <krystian@ezpear.com> patch
+							if($conf_use_nated_vhost=="yes"){
+								$q="select port from $pro_mysql_ssl_ips_table where ip_addr='${subdomain["ssl_ip"]}' and available='no';";
+								$r=mysql_query($q)or die("Cannot query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+								$n = mysql_num_rows($r);
+								if($n > 0){
+									$row=mysql_fetch_array($r);
+									$port=$row["port"];
+									$ip_vhost=$ip_to_write;
+									if(empty($port)){
+										$port = "443";
+									}
+								}else{
+									$port = "443";
+									$ip_vhost = $subdomain["ssl_ip"];
+								 }
+							}else{
+								$port = "443";
+							}
+							// End of <krystian@ezpear.com> patch
 						}
 					}
 
@@ -590,15 +665,19 @@ AND $pro_mysql_admin_table.adm_login=$pro_mysql_domain_table.owner;";
 							$vhost_file .= "<VirtualHost ".$ip_to_write.":80>\n";
 							break;
 						case "ssl":
-							$vhost_file .= "Listen ".$subdomain["ssl_ip"].":443\n";
-							$vhost_file .= "<VirtualHost ".$subdomain["ssl_ip"].":443>\n";
+							//if($conf_use_nated_vhost=="no"){
+							//	$vhost_file .= "Listen ".$ip_vhost.":$port\n";
+							//}
+							$vhost_file .= "Listen ".$subdomain["ssl_ip"].":$port\n";
+							$vhost_file .= "<VirtualHost ".$subdomain["ssl_ip"].":$port>\n";
 							$vhost_file .= "	SSLEngine on\n";
 							$vhost_file .= "	SSLCertificateFile $ssl_cert_folder_path/".$web_subname.".".$web_name.".cert.cert\n";
 							$vhost_file .= "	SSLCertificateKeyFile $ssl_cert_folder_path/".$web_subname.".".$web_name.".cert.key\n";
 							break;
 						}
 						$vhost_file .= "	ServerName $web_subname.$web_name
-	Alias /stats $web_path/$web_name/subdomains/$web_subname/logs\n";
+	Alias /stats $web_path/$web_name/subdomains/$web_subname/logs
+	Alias /awstats-icon /usr/share/awstats/icon\n";
 						// Disable the site if expired
 						if($site_expired == "yes"){
 							$document_root = $conf_generated_file_path."/expired_site";
@@ -612,17 +691,18 @@ $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
 	<Location />
 		php_admin_value open_basedir \"$web_path:$conf_php_library_path:$conf_php_additional_library_path:\"
 	</Location>
-	$cgi_directive\n";
+	$cgi_directive\n".get_defaultCharsetDirective($subdomain["add_default_charset"]);
 						}
 						$vhost_file .= "	ErrorLog $web_path/$web_name/subdomains/$web_subname/logs/error.log
 	LogSQLTransferLogTable $log_tablename\$xfer
 	LogSQLScoreDomain $web_name
 	LogSQLScoreSubdomain $web_subname
-	LogSQLScoreTable dtc.http_accounting
-	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4
+	LogSQLScoreTable $conf_mysql_db.http_accounting
+	DirectoryIndex index.php index.cgi index.pl index.htm index.html index.php4$custom_directives
 </VirtualHost>
 
 ";
+						$logrotate_file .= "$web_path/$web_name/subdomains/$web_subname/logs/error.log ";
 						$num_generated_vhosts += $num_rows2;
 					}
 				}
@@ -630,7 +710,7 @@ $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
 	        }
 	}
 
-	// Ecriture du fichier
+	// Writting the vhosts.conf file
 	$filep = fopen("$conf_generated_file_path/$conf_apache_vhost_path", "w+");
 	if( $filep == NULL){
 		die("Cannot open $conf_generated_file_path/$conf_apache_vhost_path file for writting");
@@ -640,25 +720,84 @@ $vhost_more_conf	php_admin_value safe_mode $safe_mode_value
 	fclose($filep);
 	$console .= "$num_generated_vhosts vhosts generated !<br>";
 
+	// Writting the vhost_check_dir script
 	$filep = fopen("$conf_generated_file_path/vhost_check_dir","w+");
 	if( $filep == NULL){
-		die("Cannot open $conf_generated_file_path/vhost_check_dir file for writting");
+		echo("Cannot open $conf_generated_file_path/vhost_check_dir file for writting");
+	}else{
+		fwrite($filep,$chk_dir_script);
+		fclose($filep);
 	}
-	fwrite($filep,$chk_dir_script);
-	fclose($filep);
 	$console .= "vhost_check_dir.sh script written !<br>";
 
+	// Writing the vhost_check_ssl_cert script
 	$chk_certs_script .= "exit \$EXIT_VAL";
 	$filep = fopen("$conf_generated_file_path/vhost_check_ssl_cert","w+");
 	if( $filep == NULL){
-		die("Cannot open $conf_generated_file_path/vhost_check_ssl_cert file for writting");
+		echo("Cannot open $conf_generated_file_path/vhost_check_ssl_cert file for writting");
+	}else{
+		fwrite($filep,$chk_certs_script);
+		fclose($filep);
+		chmod("$conf_generated_file_path/vhost_check_ssl_cert",0700);
 	}
-	fwrite($filep,$chk_certs_script);
-	fclose($filep);
-	chmod("$conf_generated_file_path/vhost_check_ssl_cert",0700);
 	$console .= "vhost_check_ssl_cert script written !<br>";
 
+	// Writing the logrotate configuration file
+	if($logrotate_file != ""){
+			$fname = "";
+			if( file_exists("/etc/dtc/logrotate.template") ){
+				$fname = "/etc/dtc/logrotate.template";
+			}else if( file_exists("/usr/local/etc/dtc/logrotate.template") ){
+				$fname = "/usr/local/etc/dtc/logrotate.template";
+			}
+			if($fname != ""){
+				$fp = fopen($fname,"r");
+				if($fp != NULL){
+					$logrotate_template = fread($fp,filesize($fname));
+					fclose($fp);
+				}else{
+					$logrotate_template = "";
+				}
+			}else{
+					$logrotate_template = "";
+			}
+			$logrotate_file .= " {
+$logrotate_template
+
+	sharedscripts
+";
+		if($conf_apache_version == "2"){
+			$logrotate_file .= "	postrotate
+		if [ -f /var/run/apache2.pid ]; then
+			/etc/init.d/apache2 restart > /dev/null
+		fi
+	endscript
+}
+";
+		}else{
+			$logrotate_file .= "	postrotate
+	postrotate
+		if [ -f /var/run/apache.pid ]; then \
+			if [ -x /usr/sbin/invoke-rc.d ]; then \
+				invoke-rc.d apache reload > /dev/null; \
+			else \
+				/etc/init.d/apache reload > /dev/null; \
+			fi; \
+		fi;
+	endscript
+}
+";
+		}
+		$filep = fopen("$conf_generated_file_path/logrotate","w+");
+		if( $filep == NULL){
+			echo ("Cannot open $conf_generated_file_path/logrotate for writting");
+		}else{
+			fwrite($filep,$logrotate_file);
+			fclose($filep);
+		}
+		$console .= "logrotate config file generated!<br>";
+	}
 	return true;
 }
 
-?>
+?>
\ No newline at end of file
