@@ -55,6 +55,31 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_a_vps"){
 
 	$q = "DELETE FROM $pro_mysql_vps_table WHERE id='".$_REQUEST["id"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+
+	$q = "DELETE FROM $pro_mysql_vps_stats_table WHERE vps_server_hostname='".$vps["vps_server_hostname"]."' AND vps_xen_name='".$vps["vps_xen_name"]."';";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+
+	remoteVPSAction($vps["vps_server_hostname"],$vps["vps_xen_name"],"destroy_vps");
+
+	VPS_Server_Subscribe_To_Lists($vps["vps_server_hostname"]);
+}
+
+if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "vps_server_list_remove"){
+	$q = "SELECT * FROM $pro_mysql_vps_server_table WHERE id='".$_REQUEST["edithost"]."';";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());;
+	$a = mysql_fetch_array($r);
+	$q = "DELETE FROM $pro_mysql_vps_server_lists_table WHERE hostname='".$a["hostname"]."' AND list_name='".$_REQUEST["list_name"]."';";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	resubscribe_VPS_server_list_users($_REQUEST["list_name"]);
+}
+
+if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "vps_server_list_add"){
+	$q = "SELECT * FROM $pro_mysql_vps_server_table WHERE id='".$_REQUEST["edithost"]."';";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());;
+	$a = mysql_fetch_array($r);
+	$q = "INSERT INTO $pro_mysql_vps_server_lists_table (id,hostname,list_name) VALUES ('','".$a["hostname"]."','".$_REQUEST["name"]."');";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	resubscribe_VPS_server_list_users($_REQUEST["name"]);
 }
 
 /////////////////////////
@@ -73,9 +98,6 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "validate_renewal"){
 
 // action=add_vps_to_user&vps_server_ip=66.251.193.60&vps_mem=1&vps_hdd=1&vps_duration=0000-01-00
 if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_vps_to_user"){
-// $pro_mysql_vps_table = "vps";
-// $pro_mysql_vps_ip_table = "vps_ip";
-// $pro_mysql_vps_server_table = "vps_server";
 	$q = "SELECT * FROM $pro_mysql_vps_ip_table WHERE ip_addr='".$_REQUEST["vps_server_ip"]."' AND available='yes';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
@@ -98,8 +120,8 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "add_vps_to_user"){
 
 	$exp_date = calculateExpirationDate(date("Y-m-d"),$prod["period"]);
 
-	$q = "INSERT INTO $pro_mysql_vps_table (id,owner,vps_server_hostname,vps_xen_name,start_date,expire_date,hddsize,ramsize,product_id)
-	VALUES('','$adm_login','".$a["vps_server_hostname"]."','".$a["vps_xen_name"]."','".date("Y-m-d")."','$exp_date','".$prod["quota_disk"]."','".$prod["memory_size"]."','".$_REQUEST["product_id"]."');";
+	$q = "INSERT INTO $pro_mysql_vps_table (id,owner,vps_server_hostname,vps_xen_name,start_date,expire_date,hddsize,ramsize,bandwidth_per_month_gb,product_id)
+	VALUES('','$adm_login','".$a["vps_server_hostname"]."','".$a["vps_xen_name"]."','".date("Y-m-d")."','$exp_date','".$prod["quota_disk"]."','".$prod["memory_size"]."','".$prod["bandwidth"]."','".$_REQUEST["product_id"]."');";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
 
 	// Setup the physical VPS (do the lvcreate remotly)
@@ -156,13 +178,20 @@ if(isset($_REQUEST["modify_domain_config"]) && $_REQUEST["modify_domain_config"]
 	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
 
 	// Tell the cron job to activate the changes (because ip could have change)
-	$adm_query = "UPDATE $pro_mysql_cronjob_table SET gen_vhosts='yes',gen_named='yes',reload_named='yes',restart_apache='yes' WHERE 1;";
+	$adm_query = "UPDATE $pro_mysql_cronjob_table SET gen_vhosts='yes',gen_named='yes',reload_named='yes',restart_apache='yes',gen_backup='yes' WHERE 1;";
 	mysql_query($adm_query);
 }
 
 /////////////////////////////////////
 // Domain name database management //
 /////////////////////////////////////
+if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "set_vhost_custom_directives"){
+	$q = "UPDATE $pro_mysql_subdomain_table SET customize_vhost='".$_REQUEST["custom_directives"]."' WHERE domain_name='".$_REQUEST["edithost"]."' AND subdomain_name='".$_REQUEST["subdomain"]."';";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+	$adm_query = "UPDATE $pro_mysql_cronjob_table SET gen_vhosts='yes',restart_apache='yes' WHERE 1;";
+	mysql_query($adm_query);
+}
+
 if(isset($_REQUEST["newdomain"]) && $_REQUEST["newdomain"] == "Ok"){
 	if(isHostname($_REQUEST["newdomain_name"])){
 		addDomainToUser($adm_login,$adm_pass,$_REQUEST["newdomain_name"]);
@@ -194,83 +223,9 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "delete_waiting_domain_t
 	$q = "DELETE FROM $pro_mysql_pending_queries_table WHERE id='".$_REQUEST["reqid"]."';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 }
-function deleteUserDomain($adm_login,$adm_pass,$deluserdomain,$delete_directories = false){
-	global $pro_mysql_admin_table;
-	global $pro_mysql_pop_table;
-	global $pro_mysql_ftp_table;
-	global $pro_mysql_subdomain_table;
-	global $pro_mysql_domain_table;
-	global $conf_demo_version;
-
-	global $conf_root_admin_random_pass;
-	global $conf_pass_expire;
-
-	if($conf_root_admin_random_pass == $adm_pass &&  $conf_pass_expire > mktime()){
-		$adm_query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
-	}else{
-		$adm_query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$adm_login' AND (adm_pass='$adm_pass' OR (pass_next_req='$adm_pass' AND pass_expire > '".mktime()."'));";
-	}
-	$result = mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" line ".__LINE__." file ".__FILE__."sql said ".mysql_error());
-	$num_rows = mysql_num_rows($result);
-	if($num_rows != 1) die("User not found for deletion of domain $deluserdomain !!!");
-	$row = mysql_fetch_array($result);
-	$the_admin_path = $row["path"];
-
-	// Delete all mail accounts
-	$adm_query = "DELETE FROM $pro_mysql_pop_table WHERE mbox_host='$deluserdomain';";
-	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
-
-	// Delete all mailboxs
-	$adm_query = "DELETE FROM $pro_mysql_ftp_table WHERE hostname='$deluserdomain';";
-	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
-	
-	// Delete all subdomains
-	$domupdate_query = "DELETE FROM $pro_mysql_subdomain_table WHERE domain_name='$deluserdomain';";
-	$domupdate_result = mysql_query ($domupdate_query)or die("Cannot execute query \"$domupdate_query\"");
-
-	// Delete the domain
-	$adm_query = "DELETE FROM $pro_mysql_domain_table WHERE name='$deluserdomain' LIMIT 1;";
-	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
-
-	// Delete the files of the domain name
-	if($delete_directories == true && $conf_demo_version == "no"){
-		system("rm -rf $the_admin_path/$deluserdomain");
-	}
-	triggerDomainListUpdate();
-}
 
 ///////////////////////////////////////////////////////////////
 
-function deleteMysqlUserAndDB($mysql_user){
-	global $conf_mysql_db;
-	mysql_select_db("mysql")or die("Cannot select db mysql for account management !!!");
-
-	$query = "SELECT * FROM db WHERE User='$mysql_user';";
-	$result = mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-	$num_rows = mysql_num_rows($result);
-	for($i=0;$i<$num_rows;$i++){
-		$row = mysql_fetch_array($result);
-		$db = $row["Db"];
-		// Prevent system db from deletion
-		if($db != $conf_mysql_db && $db != "mysql"){
-			$query2 = "DROP DATABASE $db";
-			mysql_query($query2)or die("Cannot execute query \"$query\" !!!");
-		}
-	}
-
-	// Prevent system user from deletion
-	if($mysql_user != "mysql" && $mysql_user != "root"){
-		$query = "DELETE FROM db WHERE User='$mysql_user';";
-		mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-		$query = "DELETE FROM user WHERE User='$mysql_user';";
-		mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-	}
-	$query = "FLUSH PRIVILEGES";
-	mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-	mysql_select_db($conf_mysql_db)or die("Cannot select db \"$conf_mysql_db\" in deleteMysqlUserAndDB() !!!");
-}
-
-
 if(isset($_REQUEST["deluserdomain"]) && $_REQUEST["deluserdomain"] != ""){
 	deleteUserDomain($adm_login,$adm_pass,$_REQUEST["deluserdomain"],true);
 
@@ -291,7 +246,9 @@ if(isset($_REQUEST["updateuserinfo"]) && $_REQUEST["updateuserinfo"] == "Ok"){
 		expire='".$_REQUEST["expire"]."',allow_add_domain='".$_REQUEST["allow_add_domain"]."',
 		nbrdb='".$_REQUEST["nbrdb"]."',prod_id='".$_REQUEST["heb_prod_id"]."',
 		resseller_flag='".$_REQUEST["resseller_flag"]."',
-		ssh_login_flag='".$_REQUEST["ssh_login_flag"]."'
+		ssh_login_flag='".$_REQUEST["ssh_login_flag"]."',
+		ftp_login_flag='".$_REQUEST["ftp_login_flag"]."',
+		pkg_install_flag='".$_REQUEST["pkg_install_flag"]."'
 		WHERE adm_login='$adm_login';";
 	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" line ".__LINE__." file ".__FILE__." ".mysql_error());
 
@@ -305,12 +262,11 @@ if(isset($_REQUEST["newadminuser"]) && $_REQUEST["newadminuser"]=="Ok"){
 	// Check for admin existance
 	// Create admin directorys
 	if(!isFtpLogin($_REQUEST["newadmin_login"])){
-		$submit_err .= $txt_err_dtc_login_format[$lang];
+		$submit_err .= _("Incorect admin login format: it should consist of only lowercase letters or numbers or the \"-\" sign, and should be between 4 and 16 chars long.<br>\n");
 		$commit_flag = "no";
-		die("Username not valid: it should be only made of letters and numbers");
 	}
 	if(!isDTCPassword($_REQUEST["newadmin_pass"])){
-		$submit_err .= $txt_err_password_format[$lang];
+		$submit_err .= _("Password consist of only letters and numbers (a-zA-Z0-9) and should be between 6 and 16 chars long.<br>\n") ;
 		$commit_flag = "no";
 	}
 	$newadmin_path = $_REQUEST["newadmin_path"]."/".$_REQUEST["newadmin_login"];
@@ -329,6 +285,8 @@ if(isset($_REQUEST["newadminuser"]) && $_REQUEST["newadminuser"]=="Ok"){
 (adm_login        ,adm_pass         ,path            )VALUES
 ('".$_REQUEST["newadmin_login"]."', '".$_REQUEST["newadmin_pass"]."','$newadmin_path') ";
 		mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+	}else{
+		echo $submit_err;
 	}
 }
 
@@ -345,81 +303,7 @@ if(isset($_REQUEST["action"]) && $_REQUEST["action"]=="valid_waiting_user"){
 }
 
 if(isset($_REQUEST["delete_admin_user"]) && $_REQUEST["delete_admin_user"] != ""){
-	$adm_query = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".$_REQUEST["delete_admin_user"]."'";
-	$result = mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
-	$num_rows = mysql_num_rows($result);
-	if($num_rows != 1) die("User not found for deletion of domain $deluserdomain !!!");
-	$row_virtual_admin = mysql_fetch_array($result);
-	$the_admin_path = $row_virtual_admin["path"];
-
-	// delete the user also mailboxs, ftp accounts, domains and subdomains in database
-	$query = "SELECT * FROM $pro_mysql_domain_table WHERE owner='".$_REQUEST["delete_admin_user"]."';";
-	$result = mysql_query($query)or die("Cannot execute query \"$query\" !!!");
-	$num_rows = mysql_num_rows($result);
-	for($i=0;$i<$num_rows;$i++){
-		$row = mysql_fetch_array($result);
-		//echo "Deleting ".$_REQUEST["delete_admin_user"]." / ".$row_virtual_admin["adm_pass"].$row["name"];
-		deleteUserDomain($_REQUEST["delete_admin_user"],$row_virtual_admin["adm_pass"],$row["name"]);
-	}
-
-	$adm_query = "DELETE FROM $pro_mysql_admin_table WHERE adm_login='".$_REQUEST["delete_admin_user"]."'";
-	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" !!!");
-
-	if($conf_demo_version == "no"){
-		system("rm -rf $the_admin_path");
-
-		// Delete all databases of the user
-		mysql_select_db("mysql")or die("Cannot select db mysql for account management !!!");
-		$query = "SELECT Host,Db,User FROM db WHERE User='".$_REQUEST["delete_admin_user"]."';";
-		$result = mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
-		$num_rows = mysql_num_rows($result);
-		for($i=0;$i<$num_rows;$i++){
-			$row = mysql_fetch_array($result);
-			echo $row["Db"];
-			$db_name[] = $row["Db"];
-		}
-		for($i=0;$i<$num_rows;$i++){
-			$query = "DROP DATABASE ".$db_name[$i];
-			mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
-		}
-
-		$query = "DELETE FROM db WHERE User='".$_REQUEST["delete_admin_user"]."';";
-		$result = mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
-		$query = "DELETE FROM user WHERE User='".$_REQUEST["delete_admin_user"]."'";
-		$result = mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
-	        mysql_query("FLUSH PRIVILEGES");
-		$result = mysql_query($query)or die("Cannot query \"$query\" !!!".mysql_error());
-		mysql_select_db($conf_mysql_db)or die("Cannot select db \"$conf_mysql_db\"	!!!");
-	}
-
-	deleteMysqlUserAndDB($_REQUEST["delete_admin_user"]);
-
-	// Tell the cron job to activate the changes
-	$adm_query = "UPDATE $pro_mysql_cronjob_table SET qmail_newu='yes',restart_qmail='yes',reload_named='yes',
-	restart_apache='yes',gen_vhosts='yes',gen_named='yes',gen_qmail='yes',gen_webalizer='yes',gen_backup='yes',gen_ssh='yes' WHERE 1;";
-	mysql_query($adm_query);
-	triggerDomainListUpdate();
-}
-
-if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "switch_generate_flag"){
-	$query = "UPDATE $pro_mysql_domain_table SET generate_flag='".$_REQUEST["switch_to"]."' WHERE name='".$_REQUEST["domain"]."';";
-	mysql_query($query)or die("Cannot execute query \"$query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
-}
-if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "switch_safe_mode_flag"){
-	$query = "UPDATE $pro_mysql_domain_table SET safe_mode='".$_REQUEST["switch_to"]."' WHERE name='".$_REQUEST["domain"]."';";
-	mysql_query($query)or die("Cannot execute query \"$query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
-
-	// Tell the cron job to activate the changes (because ip could have change)
-	$adm_query = "UPDATE $pro_mysql_cronjob_table SET gen_vhosts='yes',restart_apache='yes' WHERE 1;";
-	mysql_query($adm_query);
-}
-if(isset($_REQUEST["action"]) && $_REQUEST["action"] == "switch_sbox_protect_flag"){
-	$query = "UPDATE $pro_mysql_domain_table SET sbox_protect='".$_REQUEST["switch_to"]."' WHERE name='".$_REQUEST["domain"]."';";
-	mysql_query($query)or die("Cannot execute query \"$query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
-
-	// Tell the cron job to activate the changes (because ip could have change)
-	$adm_query = "UPDATE $pro_mysql_cronjob_table SET gen_vhosts='yes',restart_apache='yes' WHERE 1;";
-	mysql_query($adm_query);
+	DTCdeleteAdmin($_REQUEST["delete_admin_user"]);
 }
 
 //////////////////////////////
