@@ -23,5 +23,9 @@ CREATE TABLE IF NOT EXISTS new_admin (
   custom_notes text NOT NULL,
   vps_location varchar(255) NOT NULL default '',
   vps_os varchar(255) NOT NULL default '',
+  shopper_ip varchar(16) NOT NULL default '',
+  `date` date NOT NULL default '0000-00-00',
+  `time` time NOT NULL default '00:00:00',
+  last_used_lang varchar(32) NOT NULL default 'en_US',
   PRIMARY KEY  (id)
 ) TYPE=MyISAM;
