@@ -9,10 +9,14 @@ CREATE TABLE IF NOT EXISTS secpayconf (
   paypal_email varchar(128) NOT NULL default 'palpay@gplhost.com',
   paypal_sandbox enum('yes','no') NOT NULL default 'no',
   paypal_sandbox_email varchar(128) NOT NULL default '',
+  use_paypal_recurring enum('yes','no') NOT NULL default 'no',
   use_enets enum('yes','no') NOT NULL default 'no',
   use_enets_test enum('yes','no') NOT NULL default 'yes',
   enets_mid_id varchar(255) NOT NULL default '',
   enets_test_mid_id varchar(255) NOT NULL default '',
   enets_rate float(6,2) NOT NULL default '0.00',
+  use_maxmind enum('yes','no') NOT NULL default 'no',
+  maxmind_login varchar(255) NOT NULL default '',
+  maxmind_license_key varchar(255) NOT NULL default '',
   UNIQUE KEY unicrow (unicrow)
 ) TYPE=MyISAM
