@@ -1,5 +1,71 @@
 <?php
 
+function domainNamePopup($domain_name=""){
+	$out = "";
+
+	$allTLD = array(".com", ".aero", ".asia", ".biz", ".cat", ".coop", ".edu", ".gov", ".info", ".int", ".jobs", ".mil", ".mobi", ".museum", ".name", ".net",".org", ".pro", ".tel", ".travel",
+".ac",".ad",".ae",".af",".ag",".ai",".al",".am",".an",".ao",".aq",".ar",".as",".at",".au",".aw",".ax",".az",
+".ba",".bb",".bd",".be",".bf",".bg",".bh",".bi",".bj",".bm",".bn",".bo",".br",".bs",".bt",".bw",".by",".bz",
+".ca",".cc",".cd",".cf",".cg",".ch",".ci",".ck",".cl",".cm",".cn",".co",".cr",".cu",".cv",".cx",".cy",".cz",
+".de",".dj",".dk",".dm",".do",".dz",
+".ec",".ee",".eg",".er",".es",".et",".eu",
+".fi",".fj",".fk",".fm",".fo",".fr",
+".ga",".gb",".gd",".ge",".gf",".gg",".gh",".gi",".gl",".gm",".gn",".gp",".gq",".gr",".gs",".gt",".gu",".gw",".gy",
+".hk",".hm",".hn",".hr",".ht",".hu",
+".id",".ie",".il",".im",".in",".io",".iq",".ir",".is",".it",
+".je",".jm",".jo",".jp",
+".ke",".kg",".kh",".ki",".km",".kn",".kp",".kr",".kw",".ky",".kz",
+".la",".lb",".lc",".li",".lk",".lr",".ls",".lt",".lu",".lv",".ly",
+".ma",".mc",".md",".me",".mg",".mh",".mk",".ml",".mm",".mn",".mo",".mp",".mq",".mr",".ms",".mt",".mu",".mv",".mw",".mx",".my",".mz",
+".na",".nc",".ne",".nf",".ng",".ni",".nl",".no",".np",".nr",".nu",".nz",".nc",
+".om",
+".pa",".pe",".pf",".pg",".ph",".pk",".pl",".pm",".pn",".pr",".ps",".pt",".pw",".py",
+".qa",
+".re",".ro",".rs",".ru",".rw",
+".sa",".sb",".sc",".sd",".se",".sg",".sh",".si",".sk",".sl",".sm",".sn",".sr",".st",".sv",".sy",".sz",
+".tc",".td",".tf",".tg",".th",".tj",".tk",".tl",".tm",".tn",".to",".tr",".tt",".tv",".tw",".tz",
+".ua",".ug",".ac.uk",".co.uk",".gov.uk",".ltd.uk",".me.uk",".mod.uk",".net.uk",".org.uk",".plc.uk",".sch.uk",".us",".uy",".uz",
+".va",".vc",".ve",".vg",".vi",".vn",".vu",
+".wf",".ws",
+".ye",".yt",".yu",
+".za",".zm",".zw");
+
+	$keys = array_keys($allTLD);
+	$nbr_tld = sizeof($allTLD);
+	for($i=0;$i<$nbr_tld;$i++){
+		if( ereg("\\".$keys[$i]."\$",$domain_name)){
+			$selected = " selected ";
+		}else{
+			$selected = "";
+		}
+		$out .= "<option value=\"".$keys[$i]."\" $selected>". $keys[$i] ."</option>";
+	}
+	return $out;
+}
+
+function findLastUsedLangByUser($adm_login){
+	global $pro_mysql_admin_table;
+	global $pro_mysql_new_admin_table;
+
+	$q = "SELECT last_used_lang FROM $pro_mysql_admin_table WHERE adm_login='$adm_login';";
+	$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$n = mysql_num_rows($r);
+	if($n > 0){
+		$a = mysql_fetch_array($r);
+		return $a["last_used_lang"];
+	}else{
+		$q = "SELECT last_used_lang FROM $pro_mysql_new_admin_table WHERE reqadm_login='$adm_login';";
+		$r = mysql_query($q)or die("Cannot query $q line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+		$n = mysql_num_rows($r);
+		if($n > 0){
+			$a = mysql_fetch_array($r);
+			return $a["last_used_lang"];
+		}else{
+			return false;
+		}
+	}
+}
+
 function findInvoicingCompany ($service_location,$client_country_code){
 	global $pro_mysql_invoicing_table;
 	global $conf_default_company_invoicing;
@@ -213,7 +279,7 @@ function checkSubdomainFormat($name){
 	if($name == ""){
 		return false;
 	}
-	if(ereg("^([a-z0-9]+)([.a-z0-9-]*)([a-z0-9]+)\$",$name))
+	if(ereg("^([a-z0-9\_]+)([.a-z0-9\_-]*)([.a-z0-9]+)\$",$name))
 		return true;
 	else{
 		if(ereg("^([a-z0-9])\$",$name))
@@ -223,9 +289,19 @@ function checkSubdomainFormat($name){
 	}
 }
 
+// Check if a string is an ssh key
+// TO BE DONE!!!
+function isSSHKey($ssh_key){
+	if(ereg("^ssh-[rd]s[as] [a-zA-Z+/=]+\$",$ssh_key)){
+		return true;
+	}else{
+		return false;
+	}
+}
+
 // Check for email addr we allow to create using DTC
 function isMailbox($mailbox){
-	$reg = "^([a-z0-9]+)([.a-z0-9-]+)\$";
+	$reg = "^([a-zA-Z0-9])|([a-zA-Z0-9]+)([_.a-zA-Z0-9-]+)\$";
 	if(!ereg($reg,$mailbox))	return false;
 	else			return true;
 }
@@ -254,14 +330,14 @@ function isHostname($hostname){
 // Check for email addr we allow to create using DTC
 function isFtpLogin($mailbox){
 	if(isValidEmail($mailbox))	return true;
-	$reg = "^([a-z0-9]+)([.a-z0-9-]+)\$";
+	$reg = "^([a-zA-Z0-9]+)([.a-zA-Z0-9-]+)\$";
 	if(!ereg($reg,$mailbox))	return false;
 	else			return true;
 }
 
 // Check for validity of a database name
 function isDatabase($db){
-	$reg = "^([0-9a-z]+)([0-9a-z]+)\$";
+	$reg = "(^[a-zA-Z0-9]+([\_]*)[a-zA-Z0-9]+)\$";
 	if(!ereg($reg,$db))	return false;
 	else			return true;
 }
@@ -411,8 +487,8 @@ function addDedicatedToUser($adm_login,$server_hostname,$product_id){
 	$product = mysql_fetch_array($r);
 	
 	$exp_date = calculateExpirationDate(date("Y-m-d"),$product["period"]);
-	$q = "INSERT INTO $pro_mysql_dedicated_table (id,owner,server_hostname,start_date,expire_date,hddsize,ramsize,product_id)
-	VALUES('','$adm_login','$server_hostname','".date("Y-m-d")."','$exp_date','".$product["quota_disk"]."','".$product["memory_size"]."','$product_id');";
+	$q = "INSERT INTO $pro_mysql_dedicated_table (id,owner,server_hostname,start_date,expire_date,hddsize,ramsize,product_id,bandwidth_per_month_gb )
+	VALUES('','$adm_login','$server_hostname','".date("Y-m-d")."','$exp_date','".$product["quota_disk"]."','".$product["memory_size"]."','$product_id','".$product["bandwidth"]."');";
 	$r = mysql_query($q)or die("Cannot query : \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 	return ;
 }
@@ -420,7 +496,95 @@ function addDedicatedToUser($adm_login,$server_hostname,$product_id){
 ////////////////////////////
 // Add a VPS to one admin //
 ////////////////////////////
-function addVPSToUser($adm_login,$vps_server_hostname,$product_id){
+// Redo the list of subscriber to a list: to be called when adding / removing a VPS user
+function resubscribe_VPS_server_list_users($list_name){
+	global $pro_mysql_vps_server_lists_table;
+	global $pro_mysql_vps_table;
+	global $pro_mysql_admin_table;
+	global $pro_mysql_client_table;
+	global $pro_mysql_list_table;
+	global $pro_mysql_domain_table;
+
+	global $conf_main_domain;
+
+	$q = "SELECT * FROM $pro_mysql_list_table WHERE domain='$conf_main_domain' AND name='$list_name';";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());;
+	$n = mysql_num_rows($r);
+	if($n != 1)	die("Mailing list not found line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$a = mysql_fetch_array($r);
+
+	$q = "SELECT $pro_mysql_admin_table.path FROM $pro_mysql_admin_table,$pro_mysql_domain_table
+	WHERE $pro_mysql_domain_table.name='$conf_main_domain'
+	AND $pro_mysql_admin_table.adm_login = $pro_mysql_domain_table.owner";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());;
+	$n = mysql_num_rows($r);
+	if($n != 1)	die("Admin of main domain not found line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+	$a = mysql_fetch_array($r);
+	$path = $a["path"]."/$conf_main_domain/lists/".$conf_main_domain."_".$list_name."/subscribers.d";
+
+	$file_list = array();
+	if (is_dir($path)) {
+		if ($dh = opendir($path)) {
+			while (($file = readdir($dh)) !== false) {
+				$fullpath = $path . "/" . $file;
+				if(filetype($fullpath) != "dir"){
+					$file_list[] = $fullpath;
+				}
+			}
+			closedir($dh);
+		}
+	}
+	$nbr_file = sizeof($file_list);
+	for($i=0;$i<$nbr_file;$i++){
+		unlink($file_list[$i]);
+	}
+
+	$q = "SELECT $pro_mysql_client_table.email
+	FROM $pro_mysql_vps_server_lists_table,$pro_mysql_vps_table,$pro_mysql_admin_table,$pro_mysql_client_table
+	WHERE $pro_mysql_vps_server_lists_table.list_name = '$list_name'
+	AND $pro_mysql_vps_server_lists_table.hostname = $pro_mysql_vps_table.vps_server_hostname
+	AND $pro_mysql_admin_table.adm_login = $pro_mysql_vps_table.owner
+	AND $pro_mysql_client_table.id = $pro_mysql_admin_table.id_client
+	AND $pro_mysql_client_table.email!=''
+	GROUP BY $pro_mysql_client_table.email ORDER BY $pro_mysql_client_table.email;";
+	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());;
+	$n = mysql_num_rows($r);
+	$old_file = "";
+	$addr_list = "";
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		$fname = substr($a["email"],0,1);
+		if($fname == $old_file || $old_file == ""){
+			$addr_list .= $a["email"]."\n";
+		}else{
+			$fullpath = $path."/".$old_file;
+			$fp = fopen($fullpath,"w+");
+			fwrite($fp,$addr_list);
+			fclose($fp);
+			$addr_list = $a["email"]."\n";
+		}
+		$old_file = $fname;
+	}
+	if($n > 0){
+		$fullpath = $path."/".substr($a["email"],0,1);
+		$fp = fopen($fullpath,"w+");
+		fwrite($fp,$addr_list);
+		fclose($fp);
+	}
+}
+
+function VPS_Server_Subscribe_To_Lists($vps_server_hostname){
+	global $pro_mysql_vps_server_lists_table;
+	$q = "SELECT * FROM $pro_mysql_vps_server_lists_table WHERE hostname='$vps_server_hostname';";
+	$r = mysql_query($q)or die("Cannot query : \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+	$n = mysql_num_rows($r);
+	for($i=0;$i<$n;$i++){
+		$a = mysql_fetch_array($r);
+		resubscribe_VPS_server_list_users($a["list_name"]);
+	}
+}
+
+function addVPSToUser($adm_login,$vps_server_hostname,$product_id,$operating_system="debian"){
 	global $pro_mysql_product_table;
 	global $pro_mysql_vps_ip_table;
 	global $pro_mysql_vps_table;
@@ -442,11 +606,17 @@ function addVPSToUser($adm_login,$vps_server_hostname,$product_id){
 	$r = mysql_query($q)or die("Cannot query : \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
 
 	$exp_date = calculateExpirationDate(date("Y-m-d"),$product["period"]);
-	$q = "INSERT INTO $pro_mysql_vps_table (id,owner,vps_server_hostname,vps_xen_name,start_date,expire_date,hddsize,ramsize,product_id)
-	VALUES('','$adm_login','".$vps_ip["vps_server_hostname"]."','".$vps_ip["vps_xen_name"]."','".date("Y-m-d")."','$exp_date','".$product["quota_disk"]."','".$product["memory_size"]."','$product_id');";
+	$q = "INSERT INTO $pro_mysql_vps_table (id,owner,vps_server_hostname,vps_xen_name,start_date,expire_date,hddsize,ramsize,product_id,bandwidth_per_month_gb,operatingsystem)
+	VALUES('','$adm_login','".$vps_ip["vps_server_hostname"]."','".$vps_ip["vps_xen_name"]."','".date("Y-m-d")."','$exp_date','".$product["quota_disk"]."','".$product["memory_size"]."','$product_id','".$product["bandwidth"]."','$operating_system');";
 	$r = mysql_query($q)or die("Cannot query : \"$q\" line ".__LINE__." file ".__FILE__." sql said ".mysql_error());
+
+	// Subscribe user to the lists of the VPS
+	VPS_Server_Subscribe_To_Lists($vps_server_hostname);
+
 	return $vps_ip["vps_xen_name"];
 }
+
+
 ///////////////////////////////
 // Add a domain to one admin //
 ///////////////////////////////
@@ -491,6 +661,9 @@ function addDomainToUser($adm_login,$adm_pass,$domain_name,$domain_password=""){
 		exec("if [ ! -e $admin_path/$domain_name/usr ]; then ln -s subdomains/www/usr  $admin_path/$domain_name/usr; fi");
 		exec("if [ ! -e $admin_path/$domain_name/dev ]; then ln -s subdomains/www/dev  $admin_path/$domain_name/dev; fi");
 		exec("if [ ! -e $admin_path/$domain_name/etc ]; then ln -s subdomains/www/etc  $admin_path/$domain_name/etc; fi");
+
+		exec("if [ `uname -m` = \"x86_64\" ] ; then if [ ! -e $admin_path/$domain_name/lib64 ] ; then ln -s subdomains/www/lib $admin_path/$domain_name/lib64 ; fi ; fi");
+
 		// now for the admin user chroot links
 		exec("if [ ! -e $admin_path/bin ]; then ln -s $domain_name/subdomains/www/bin  $admin_path/bin; fi");
 		exec("if [ ! -e $admin_path/var ]; then ln -s $domain_name/subdomains/www/var  $admin_path/var; fi");
@@ -502,6 +675,8 @@ function addDomainToUser($adm_login,$adm_pass,$domain_name,$domain_password=""){
 		exec("if [ ! -e $admin_path/dev ]; then ln -s $domain_name/subdomains/www/dev  $admin_path/dev; fi");
 		exec("if [ ! -e $admin_path/etc ]; then ln -s $domain_name/subdomains/www/etc  $admin_path/etc; fi");
 
+		exec("if [ `uname -m` = \"x86_64\" ] ; then if [ ! -e $admin_path/lib64 ] ; then ln -s subdomains/www/lib $admin_path/lib64 ; fi ; fi");
+
 		system ("cp -rup $conf_generated_file_path/template/* $admin_path/$domain_name/subdomains/www/html");
 	}
 
@@ -518,6 +693,14 @@ function addDomainToUser($adm_login,$adm_pass,$domain_name,$domain_password=""){
 	mysql_query($adm_query);
 }
 
+function drawSubmitButton($text){
+	return "<div class=\"input_btn_container\" onMouseOver=\"this.className='input_btn_container-hover';\" onMouseOut=\"this.className='input_btn_container';\">
+ <div class=\"input_btn_left\"></div>
+ <div class=\"input_btn_mid\"><input class=\"input_btn\" type=\"submit\" name=\"submit\" value=\"". $text. "\"></div>
+ <div class=\"input_btn_right\"></div>
+</div>";
+}
+
 function drawPercentBar($value,$max,$double="yes"){
 	$alts = "";
 	$altn = "";
@@ -586,10 +769,10 @@ function smartDate($date){
 }
 
 function smartByte($bytes){
-	if($bytes>1024*1024*1024)	return round(($bytes / (1024*1024*1024)),3) ." GBytes";
-	if($bytes>1024*1024)		return round(($bytes / (1024*1024)),3) ." MBytes";
-	if($bytes>1024)				return round(($bytes / 1024),3) ." kBytes";
-	return $bytes." Bytes";
+	if($bytes>1024*1024*1024)	return round(($bytes / (1024*1024*1024)),3) ." ". _("GBytes");
+	if($bytes>1024*1024)		return round(($bytes / (1024*1024)),3) ." ". _("MBytes");
+	if($bytes>1024)				return round(($bytes / 1024),3) ." "._("kBytes");
+	return $bytes." "._("Bytes");
 }
 
 function calculateExpirationDate($date,$period){
