@@ -108,7 +108,10 @@ function dtcFromOkDraw($delete_form=""){
 //   forward => array(var1,var2...) -> names of the variables to forward
 //   [skip_deletion] => "yes" -> Do not display the deletion option
 //   [skip_creation] => "yes" -> Do not display the new item line
+//   [update_check_callback] => Callback to accept or deny the update of a record.
+//   [insert_check_callback] => callback to accept or deny the insert of a record
 //   [where_condition] => "blabla='hop' AND titi='toto'" -> Condition of the display of the table
+//   [order_by] => "fldname_1" -> Condition pour le order by
 //   cols => array(
 //		"field0" => array(	-> Note this will be use as a WHERE blabla='titi' for the UPDATE statement
 //			type => "id",
@@ -144,11 +147,10 @@ function dtcDatagrid($dsc){
 	global $adm_pass;
 	global $txt_action;
 	global $lang;
+	global $action_error_txt;
 
 	global $gfx_form_entry_label_background;
 
-	$out = "<h3>".$dsc["title"]."</h3>";
-
 	$nbr_forwards = sizeof($dsc["forward"]);
 	$keys_fw = array_keys($dsc["forward"]);
 
@@ -180,6 +182,8 @@ function dtcDatagrid($dsc){
 		$flds .= $keys[$i];
 	}
 
+	$action_error_txt = "";
+
 	if(isset($_REQUEST["action"])){
 		$added_one = "no";
 		switch($_REQUEST["action"]){
@@ -229,7 +233,15 @@ function dtcDatagrid($dsc){
 				$qflds .= ", ".$exploded[0];
 				$vals .= ", ".$exploded[1];
 			}
-			$q = "INSERT INTO ".$dsc["table_name"]." ($qflds) VALUES($vals);";
+			if( isset($dsc["insert_check_callback"]) ){
+				if ( $dsc["insert_check_callback"]() ){
+					$q = "INSERT INTO ".$dsc["table_name"]." ($qflds) VALUES($vals);";
+				}else{
+					$q = "";
+				}
+			}else{
+				$q = "INSERT INTO ".$dsc["table_name"]." ($qflds) VALUES($vals);";
+			}
 			break;
 		case $dsc["action"]."_edit":
 			$vals = "";
@@ -254,6 +266,20 @@ function dtcDatagrid($dsc){
 					$vals .= " ".$keys[$i]."='".$dsc["cols"][ $keys[$i] ]["values"][$index_val]."' ";
 					$added_one = "yes";
 					break;
+				case "password":
+					if($added_one == "yes"){
+                                                $vals .= ", ";
+                                        }
+                                        $vals .= " ".$keys[$i]."='".$_REQUEST[ $keys[$i] ]."' ";
+                                        $added_one = "yes";
+					// if the crypt field is set, then we use this as the SQL field to populate the crypted password into
+					if(isset($dsc["cols"][ $keys[$i] ]["cryptfield"])){
+						if($added_one == "yes"){
+							$vals .= ", ";
+						}
+						$vals .= " ".$dsc["cols"][ $keys[$i] ]["cryptfield"]."='".crypt($_REQUEST[ $keys[$i] ], dtc_makesalt())."' ";
+					}
+                                        break;
 				default:
 					if($added_one == "yes"){
 						$vals .= ", ";
@@ -263,7 +289,15 @@ function dtcDatagrid($dsc){
 					break;
 				}
 			}
-			$q = "UPDATE ".$dsc["table_name"]." SET $vals WHERE $id_name='$id';";
+			if( isset($dsc["update_check_callback"]) ){
+				if ( $dsc["update_check_callback"]() ){
+					$q = "UPDATE ".$dsc["table_name"]." SET $vals WHERE $id_name='$id';";
+				}else{
+					$q = "";
+				}
+			}else{
+				$q = "UPDATE ".$dsc["table_name"]." SET $vals WHERE $id_name='$id';";
+			}
 			break;
 		case $dsc["action"]."_delete":
 			for($i=0;$i<$nbr_fld;$i++){
@@ -279,10 +313,16 @@ function dtcDatagrid($dsc){
 			break;
 		}
 		if($q != ""){
-			$r = mysql_query($q)or die("Cannot query $q in ".__FILE__." line ".__LINE__." sql said: ".mysql_query());
+			$r = mysql_query($q)or die("Cannot query $q in ".__FILE__." line ".__LINE__." sql said: ".mysql_error());
 		}
 	}
 
+	$out = "<h3>".$dsc["title"]."</h3>";
+
+	if( $action_error_txt != ""){
+		$out .= "<font color=\"red\">" . $action_error_txt . "</font><br>";
+	}
+
 	// Display of all the titles of the table
 	$out .= "<table class=\"dtcDatagrid_table_props\" border=\"0\" cellpadding=\"2\" cellspacing=\"0\">";
 	$out .= "<tr>";
@@ -322,7 +362,12 @@ function dtcDatagrid($dsc){
 	}else{
 		$where = "";
 	}
-	$q = "SELECT $sql_fld_list FROM ".$dsc["table_name"]." $where;";
+	if(isset($dsc["order_by"])){
+		$order_by = " ORDER BY ".$dsc["order_by"]." ";
+	}else{
+		$order_by = "";
+	}
+	$q = "SELECT $sql_fld_list FROM ".$dsc["table_name"]." $where $order_by;";
 	$r = mysql_query($q)or die("Cannot query $q in ".__FILE__." line ".__LINE__." sql said: ".mysql_error());
 	$n = mysql_num_rows($r);
 	for($i=0;$i<$n;$i++){
@@ -430,7 +475,7 @@ function dtcDatagrid($dsc){
 					}
 					$out .= "<option value=\"".$dsc["cols"][ $keys[$j] ]["values"][$x]."\" $selected>".$display_value_popup."</option>";
 				}
-				$out .= "<select>";
+				$out .= "</select>";
 				$out .= "</td>";
 				break;
 			case "id":
@@ -538,7 +583,7 @@ function dtcDatagrid($dsc){
 					}
 					$out .= "<option value=\"".$dsc["cols"][ $keys[$j] ]["values"][$x]."\">".$display_value_popup."</option>";
 				}
-				$out .= "<select>";
+				$out .= "</select>";
 				$out .= "</td>";
 				break;
 			case "id":
@@ -638,6 +683,11 @@ function dtcListItemsEdit($dsc){
 
 	// Condition to add to each queries
 	$where = "WHERE 1";
+	if( isset($dsc["order_by"])){
+		$order_by = " ORDER BY ". $dsc["order_by"];
+	}else{
+		$order_by = "";
+	}
 	$added_insert_names = "";
 	$added_insert_values = "";
 	if(isset($dsc["where_list"])){
@@ -689,7 +739,7 @@ function dtcListItemsEdit($dsc){
 			default:
 				break;
 			}
-			if( isset($dsc["cols"][ $keys[$i] ]["check"]) && (!isset($dsc["cols"][ $keys[$i] ]["disable_edit"]) || $dsc["cols"][ $keys[$i] ]["disable_edit"] != "yes") ){
+			if( isset($dsc["cols"][ $keys[$i] ]["check"])){
 				switch($dsc["cols"][ $keys[$i] ]["check"]){
 				case "subdomain":
 					if( !checkSubdomainFormat($_REQUEST[ $keys[$i] ]) ){
@@ -751,6 +801,19 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "mail_alias_group":
+					$mail_alias_group_raw = trim($_REQUEST[ $keys[$i] ],"\r\n");
+					$mail_alias_nocr = str_replace("\r", "", $mail_alias_group_raw);
+					$mail_alias_array = split("\n", $mail_alias_nocr);
+					for($x=0;$x<count($mail_alias_array);$x++)
+					{
+						if ( ! isValidEmail($mail_alias_array[$x]) )
+						{
+							$commit_flag = "no";
+							$commit_err .= $mail_alias_array[$x].": not a valid email format.<br>";
+						}
+					}
+					break;
 				case "dtc_pass":
 					if( !isDTCPassword($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
@@ -792,6 +855,34 @@ function dtcListItemsEdit($dsc){
 			$commit_flag = "no";
 			$commit_err = "Max number of items reached!";
 		}
+		if(isset($dsc["check_unique"])){
+			$nbr_unique_check = sizeof($dsc["check_unique"]);
+			$where_clause = "";
+			for($i=0;$i<$nbr_unique_check;$i++){
+				if($i != 0){
+					$where_clause .= " AND ";
+				}
+				if( isset ($dsc["cols"][ $dsc["check_unique"][$i] ]["happen_domain"]) ){
+					$where_clause .= $dsc["check_unique"][$i] . "='".$_REQUEST[ $dsc["check_unique"][$i] ]  .  $dsc["cols"][ $dsc["check_unique"][$i] ]["happen_domain"]."' ";
+				}else{
+					$where_clause .= $dsc["check_unique"][$i] . "='".$_REQUEST[ $dsc["check_unique"][$i] ]."' ";
+				}
+			}
+			if( !isset($dsc["check_unique_use_where_list"]) || $dsc["check_unique_use_where_list"] == "yes"){
+				$nbr_where_list_fld = sizeof($dsc["where_list"]);
+				$where_list_keys_fld = array_keys($dsc["where_list"]);
+				for($i=0;$i<$nbr_where_list_fld;$i++){
+					$where_clause .= " AND ".$where_list_keys_fld[$i]."='".$dsc["where_list"][ $where_list_keys_fld[$i] ]."'";
+				}
+			}
+			$q = "SELECT * FROM ".$dsc["table_name"]." WHERE $where_clause ";
+			$r = mysql_query($q)or die("Cannot query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
+			$n = mysql_num_rows($r);
+			if($n > 0){
+				$commit_flag = "no";
+				$commit_err = $dsc["check_unique_msg"];
+			}
+		}
 		// Build the request
 		$fld_names = "";
 		$values = "";
@@ -814,6 +905,15 @@ function dtcListItemsEdit($dsc){
 					}else{
 						$values .= "'".addslashes($_REQUEST[ $keys[$i] ])."'";
 					}
+					// if the crypt field is set, then we use this as the SQL field to populate the crypted password into
+					if(isset($dsc["cols"][ $keys[$i] ]["cryptfield"])){
+						if($added_one == "yes"){
+							$fld_names .= ",";
+							$values .= ",";
+						}
+						$fld_names .= $dsc["cols"][ $keys[$i] ]["cryptfield"];
+						$values .= "'".crypt($_REQUEST[ $keys[$i] ], dtc_makesalt())."'";
+					}
 				}
 				$added_one = "yes";
 				break;
@@ -875,7 +975,7 @@ function dtcListItemsEdit($dsc){
 				$out .= "<font color=\"red\">Cannot query $q in ".__FILE__." line ".__LINE__." sql said: ".mysql_error()."</font>";
 			}
 		}else{
-			$out .= "<font color=\"red\">Could not commit the changes because of an error in field format: <br>$commit_err</font>";
+			$out .= "<font color=\"red\">Could not commit the changes because of an error in field format: <br>$commit_err</font><br>";
 		}
 	}else if( isset($_REQUEST["action"]) && $_REQUEST["action"] == $dsc["action"]."_save_item" ){
 		// Todo: do the fields checkings
@@ -965,6 +1065,19 @@ function dtcListItemsEdit($dsc){
 						}
 					}
 					break;
+				case "mail_alias_group":
+					$mail_alias_group_raw = trim($_REQUEST[ $keys[$i] ],"\r\n");
+					$mail_alias_nocr = str_replace("\r", "", $mail_alias_group_raw);
+					$mail_alias_array = split("\n", $mail_alias_nocr);
+					for($x=0;$x<count($mail_alias_array);$x++)
+					{
+						if ( ! isValidEmail($mail_alias_array[$x]) )
+						{
+							$commit_flag = "no";
+							$commit_err .= $mail_alias_array[$x].": not a valid email format.<br>";
+						}
+					}
+					break;
 				case "dtc_pass":
 					if( !isDTCPassword($_REQUEST[ $keys[$i] ]) ){
 						if( !isset($dsc["cols"][ $keys[$i] ]["can_be_empty"])
@@ -1031,6 +1144,13 @@ function dtcListItemsEdit($dsc){
 						$reqs .= $keys[$i]."='default'";
 					}else{
 						$reqs .= $keys[$i]."='".addslashes($_REQUEST[ $keys[$i] ]).$happen."'";
+						// if the crypt field is set, then we use this as the SQL field to populate the crypted password into
+						if(isset($dsc["cols"][ $keys[$i] ]["cryptfield"])){
+							if($added_one == "yes"){
+								$reqs .= ", ";
+							}
+							$reqs .= " ".$dsc["cols"][ $keys[$i] ]["cryptfield"]."='".crypt($_REQUEST[ $keys[$i] ], dtc_makesalt())."' ";
+						}
 					}
 					$added_one = "yes";
 				}
@@ -1088,7 +1208,7 @@ function dtcListItemsEdit($dsc){
 	}
 
 	// We have to query it again, in case an insert or a delete has occured!
-	$q = "SELECT ".$dsc["id_fld"].",".$dsc["list_fld_show"]." FROM ".$dsc["table_name"]." $where;";
+	$q = "SELECT ".$dsc["id_fld"].",".$dsc["list_fld_show"]." FROM ".$dsc["table_name"]." $where $order_by;";
 	$r_item_list = mysql_query($q)or die("Cannot query $q in ".__FILE__." line ".__LINE__." sql said: ".mysql_error());
 	$current_num_items = mysql_num_rows($r_item_list);
 
