@@ -20,8 +20,6 @@ function fetchTable($query){
 
 function fetchMailboxInfos($adm_email_login,$adm_email_pass){
 	global $pro_mysql_pop_table;
-	global $lang;
-	global $txt_wrong_user_or_password_or_timeout_expire;
 
 	$ret["err"] = 0;
 	$ret["mesg"] = "No error";
@@ -38,7 +36,7 @@ function fetchMailboxInfos($adm_email_login,$adm_email_pass){
 		return $ret;
 	}
 	if(mysql_num_rows($r) != 1){
-		$ret["mesg"] = $txt_wrong_user_or_password_or_timeout_expire[$lang];
+		$ret["mesg"] = _("Wrong user or password, or timeout expired!") ;
 		$ret["err"] = -1;
 		return $ret;
 	}
@@ -321,8 +319,6 @@ function randomizePassword($adm_login,$adm_input_pass){
 	global $adm_realpass;
 	global $adm_pass;
 	global $adm_random_pass;
-	global $txt_wrong_user_or_password_or_timeout_expire;
-	global $lang;
 	global $conf_session_expir_minute;
 
 	$ret["err"] = 0;
@@ -363,12 +359,12 @@ OR (pass_next_req='$adm_pass' AND pass_expire > '".mktime()."'));";
 			$num_rows = mysql_num_rows($result);
 
 			if($num_rows != 1){
-				$ret["mesg"] = $txt_wrong_user_or_password_or_timeout_expire[$lang];
+				$ret["mesg"] = _("Wrong user or password, or timeout expired!") ;
 				$ret["err"] = -1;
 				return $ret;
 			}
 		}else{
-			$ret["mesg"] = $txt_wrong_user_or_password_or_timeout_expire[$lang];
+			$ret["mesg"] = _("Wrong user or password, or timeout expired!") ;
 			$ret["err"] = -1;
 			return $ret;
 		}
@@ -411,30 +407,27 @@ OR (pass_next_req='$adm_pass' AND pass_expire > '".mktime()."'));";
 }
 
 function fetchAdminData($adm_login,$adm_input_pass){
-        global $pro_mysql_domain_table;
-        global $pro_mysql_admin_table;
-        global $pro_mysql_list_table;
-        global $pro_mysql_pop_table;
+	global $pro_mysql_domain_table;
+	global $pro_mysql_admin_table;
+	global $pro_mysql_list_table;
+	global $pro_mysql_pop_table;
+	global $pro_mysql_mailaliasgroup_table;
 	global $pro_mysql_ftp_table;
 	global $pro_mysql_ssh_table;
-        global $pro_mysql_subdomain_table;
-        global $pro_mysql_config_table;
-        global $pro_mysql_vps_table;
-        global $pro_mysql_vps_ip_table;
-        global $pro_mysql_vps_server_table;
-        global $pro_mysql_dedicated_table;
-        global $panel_type;
+	global $pro_mysql_subdomain_table;
+	global $pro_mysql_config_table;
+	global $pro_mysql_vps_table;
+	global $pro_mysql_vps_ip_table;
+	global $pro_mysql_vps_server_table;
+	global $pro_mysql_dedicated_table;
+	global $panel_type;
 
 	global $conf_session_expir_minute;
 
-//	global $adm_login;
 	global $adm_realpass;
 	global $adm_pass;
 	global $adm_random_pass;
 
-	global $txt_wrong_user_or_password_or_timeout_expire;
-	global $lang;
-
 	// This one is used by the root GUI so that you can browse your user
 	// account at the same time as him without destroying his session.
 	global $DONOT_USE_ROTATING_PASS;
@@ -452,13 +445,13 @@ function fetchAdminData($adm_login,$adm_input_pass){
 	$result = mysql_query ($query);
 	if (!$result){
 		$ret["err"] = 1;
-		$ret["mesg"]="Cannot execute query for password line ".__LINE__." file ".__FILE__." (error message removed for security reasons).";
+		$ret["mesg"] = "Cannot execute query for password line ".__LINE__." file ".__FILE__." (MySQL error message removed for security reasons).";
 		return $ret;
 	}
 	$row = mysql_fetch_array($result);
 	if (!$row){
 		$ret["err"] = 2;
-		$ret["mesg"]="Cannot fetch user line ".__LINE__." file ".__FILE__;
+		$ret["mesg"]= _("Cannot fetch user line")." ".__LINE__." "._("file")." ".__FILE__." "._("either your login and password pair is not valid, either your session expired (timed out).");
 		return $ret;
 	}
 
@@ -578,6 +571,7 @@ function fetchAdminData($adm_login,$adm_input_pass){
 		unset($subs);
 		for($j=0;$j<$num_rows2;$j++){
 			$row2 = mysql_fetch_array($result2);
+			unset($subdomain);
 			if (!$row2)
 			{
 				$ret["err"] = 8;
@@ -691,6 +685,40 @@ function fetchAdminData($adm_login,$adm_input_pass){
 			$domain["emails"] = $emails;
 		}
 
+// Now Can add alias emails to all thoses domains !
+		$query5 = "SELECT * FROM $pro_mysql_mailaliasgroup_table WHERE domain_parent='$name' ORDER BY id;";
+		$result5 = mysql_query ($query5);
+		if (!$result5)
+		{
+			$ret["err"] = 9;
+			$ret["mesg"] = "Cannot execute query \"$query5\"";
+			return $ret;
+		}
+		$num_rows4 = mysql_num_rows($result5);
+		unset($aliases);
+		for($j=0;$j<$num_rows4;$j++){
+			$row5 = mysql_fetch_array($result5);
+			if (!$row5)
+			{
+				$ret["err"] = 10;
+				$ret["mesg"] = "Cannot fetch mailbox";
+				return $ret;
+			}
+			unset($alias);
+			$alias["autoinc"] = $row5["autoinc"];
+			$alias["id"] = $row5["id"];
+			$alias["domain_parent"] = $row5["domain_parent"];
+			$alias["delivery_group"] = $row5["delivery_group"];
+			$alias["active"] = $row5["active"];
+			$alias["start_date"] = $row5["start_date"];
+			$alias["expire_date"] = $row5["expire_date"];
+			$alias["bounce_msg"] = $row5["bounce_msg"];
+			$aliases[] = $alias;
+		}	
+		if(isset($aliases)){
+			$domain["aliases"] = $aliases;
+		}
+
 		//now to add all the mailing lists
 		$query4 = "SELECT * FROM $pro_mysql_list_table WHERE domain='$name' ORDER BY name;";
 		$result4 = mysql_query ($query4);
@@ -867,6 +895,10 @@ function fetchAdmin($adm_login, $adm_pass){
 	if($data["err"] != 0){
 		$ret["err"] = $data["err"];
 		$ret["mesg"] = $data["mesg"];
+		return $ret;
+/* I'm disabling this peace of code, I think it's quite hugly
+
+
 		$http_auth_worked = 0;
 		//if we have PHP_AUTH_USER or PHP_AUTH_PW, try to use them here
 		if (!isset($_SERVER['PHP_AUTH_USER'])) {
@@ -903,10 +935,16 @@ function fetchAdmin($adm_login, $adm_pass){
 		if ($http_auth_worked == 0){
 			return $ret;
 		}
+		*/
 	}
 	//since we are here, our login/password combo must be valid
-	$_SERVER['PHP_AUTH_USER'] = $adm_login;
-	$_SERVER['PHP_AUTH_PW'] = $adm_pass;
+
+// Note from Thomas:
+// This one I really want to kill it!
+// My code with MySQL rotating password is to avoid storing
+// things in php sessions that are by definition unsafe.
+//	$_SERVER['PHP_AUTH_USER'] = $adm_login;
+//	$_SERVER['PHP_AUTH_PW'] = $adm_pass;
 
 	$info = fetchAdminInfo($adm_login);
 	if($info["err"] != 0){
