@@ -1,27 +1,11 @@
 <?php
 
-/**
- * 
- * @package DTC
- * @version $Id: email.php,v 1.51 2007/03/28 13:06:36 dracula Exp $
- * @param unknown_type $mailbox
- * @return unknown
- */
-
 function drawImportedMail($mailbox){
 	global $adm_email_login;
 	global $adm_email_pass;
 	global $errTxt;
 	global $pro_mysql_fetchmail_table;
-	
-	global $txt_login_login;
-	global $txt_login_pass;
-	global $txt_use;
-	global $txt_action;
-	global $txt_cfg_server_address;
-	global $txt_login_title;
-	global $lang;
-	
+
 	$out = "";
 
 	if(isset($errTxt) && $errTxt != ""){
@@ -40,7 +24,7 @@ function drawImportedMail($mailbox){
 	$out .= "<table border=\"1\">
 	
 	<!-- to translate -->
-<tr><td>Address email</td><td>Mailbox type</td><td>".$txt_cfg_server_address[$lang]."</td><td>".$txt_login_title[$lang]."</td><td>".$txt_login_pass[$lang]."</td><td>".$txt_use[$lang]."</td><td>".$txt_action[$lang]."</td></tr>";
+<tr><td>". _("Address email") ."</td><td>". _("Mailbox type") ."</td><td>". _("Server address :") . "</td><td>". _("Login") ."</td><td>". _("Password:") ."</td><td>". _("Use") ."</td><td>". _("Action") ."</td></tr>";
 	for($i=0;$i<$n;$i++){
 		$a = mysql_fetch_array($r);
 		$pop3_selected = "";
@@ -140,7 +124,7 @@ http://www.gplhost.com/software-dtc.html
 
 	if($mailbox["data"]["iwall_protect"] == "yes")	$checked = " checked "; else $checked = "";
 	$out = $form_start."<input type=\"hidden\" name=\"action\" value=\"activate_antispam\"><input type=\"checkbox\" name=\"iwall_on\" value=\"yes\"$checked>Activate iGlobalWall protection
-	<input type=\"submit\" value=\"Ok\"></form>";
+	". drawSubmitButton( _("Ok") ) ."</form>";
 
 	if($mailbox["data"]["iwall_protect"] == "yes"){
 		$frm_start = "<form action=\"".$_SERVER["PHP_SELF"]."\">
@@ -192,7 +176,7 @@ http://www.gplhost.com/software-dtc.html
 	}
 	if($mailbox["data"]["clamav_protect"] == "yes")	$checked = " checked "; else $checked = "";
 	$out .= $form_start."<input type=\"hidden\" name=\"action\" value=\"activate_clamav\"><input type=\"checkbox\" name=\"clamav_on\" value=\"yes\"$checked>Activate Clamav antivirus
-	<input type=\"submit\" value=\"Ok\"></form>";
+	". drawSubmitButton( _("Ok") ) ."</form>";
 	return $out;
 }
 
@@ -215,21 +199,7 @@ function drawQuarantine($mailbox){
 	return $out;
 }
 
-function drawAdminTools_emailAccount($mailbox){
-	global $txt_change_your_password_title;
-	global $txt_repeate_password;
-	global $txt_mail_deliver_localy;
-	global $txt_mail_spam_mailbox_enable;
-	global $txt_mail_spam_mailbox;
-	global $txt_mail_redirection1;
-	global $txt_mail_redirection2;
-	global $txt_password;
-	global $txt_mail_edit;
-	global $txt_mailbox_redirection_edition;
-	global $lang;
-	global $txt_yes;
-	global $txt_no;
-	
+function drawAdminTools_emailAccount($mailbox){	
 	global $adm_email_login;
 	global $adm_email_pass;
 
@@ -239,42 +209,76 @@ function drawAdminTools_emailAccount($mailbox){
 <input type=\"hidden\" name=\"adm_email_pass\" value=\"$adm_email_pass\">
 <input type=\"hidden\" name=\"addrlink\" value=\"".$_REQUEST["addrlink"]."\">";
 
-	$change_pass_form = "<br><b><u>".$txt_change_your_password_title[$lang]."</b></u><br><br><br>
+	// Draw the form for changing the password
+	$left = "<h3>". _("Change your password:") ."</h3>
 <table cellpadding=\"0\" cellspacing=\"0\">
 <tr>
-	<td align=\"right\">".$form_start.$txt_password[$lang]."</td>
+	<td align=\"right\">".$form_start. _("Password: ") ."</td>
 	<td><input type=\"hidden\" name=\"action\" value=\"dtcemail_change_pass\"><input type=\"password\" name=\"newpass1\" value=\"\"></td>
 </tr><tr>
-	<td align=\"right\">".$txt_repeate_password[$lang]."</td>
-	<td><input type=\"password\" name=\"newpass2\" value=\"\"> <input type=\"submit\" name=\"submit\" value=\"Ok\"></form></td>
+	<td align=\"right\">". _("Confirm password: ") ."</td>
+	<td><input type=\"password\" name=\"newpass2\" value=\"\"></td>
+</tr><tr>
+	<td></td><td>". drawSubmitButton( _("Ok") ) ."</form></td>
 </tr></table>
 <br><br>";
 
-	if($mailbox["data"]["localdeliver"] == "yes"){
-		$deliverUrl = "$url_start&action=dtcemail_set_deliver_local&setval=no\"><font color=\"green\">".$txt_yes[$lang]."</font></a>";
+	if($mailbox["data"]["vacation_flag"] == "yes"){
+		$use_vacation_msg_yes_checked = " checked ";
+		$use_vacation_msg_no_checked = " ";
 	}else{
-		$deliverUrl = "$url_start&action=dtcemail_set_deliver_local&setval=yes\"><font color=\"red\">".$txt_no[$lang]."</font></a>";
+		$use_vacation_msg_yes_checked = " ";
+		$use_vacation_msg_no_checked = " checked ";
 	}
 
-	$redirect_form = "<br><b><u>".$txt_mailbox_redirection_edition[$lang]."</b></u><br><br>
-".$txt_mail_deliver_localy[$lang]." $deliverUrl
+	$left .= "<h3>Vacation message</h3>
+	".$form_start."<input type=\"hidden\" name=\"action\" value=\"dtcemail_vacation_msg\">
+<input type=\"radio\" name=\"use_vacation_msg\" value=\"yes\" $use_vacation_msg_yes_checked>"._("Yes")."<input type=\"radio\" name=\"use_vacation_msg\" value=\"no\" $use_vacation_msg_no_checked>"._("No")."
+<br>
+<textarea cols=\"40\" rows=\"7\" name=\"vacation_msg_txt\">".$mailbox["data"]["vacation_text"]."</textarea><br>
+". drawSubmitButton( _("Ok") ) ."</form>";
+
+	if($mailbox["data"]["localdeliver"] == "yes"){
+		$deliverUrl = "$url_start&action=dtcemail_set_deliver_local&setval=no\"><font color=\"green\">"._("Yes")."</font></a>";
+	}else{
+		$deliverUrl = "$url_start&action=dtcemail_set_deliver_local&setval=yes\"><font color=\"red\">"._("No")."</font></a>";
+	}
+	$right = "<h3>". _("Edit your mailbox redirections:") ."</h3>
+". _("Deliver messages locally in INBOX: ") ." $deliverUrl
 <table cellpadding=\"0\" cellspacing=\"0\">
 <tr>
-	<td align=\"right\">".$form_start.$txt_mail_redirection1[$lang]."</td>
+	<td align=\"right\">".$form_start. _("Redirection 1: ") ."</td>
 	<td><input type=\"hidden\" name=\"action\" value=\"dtcemail_edit_redirect\"><input type=\"text\" name=\"redirect1\" value=\"".$mailbox["data"]["redirect1"]."\"></td>
 </tr><tr>
-	<td>".$txt_mail_redirection2[$lang]."</td>
-	<td><input type=\"text\" name=\"redirect2\" value=\"".$mailbox["data"]["redirect2"]."\"><input type=\"submit\" name=\"submit\" value=\"Ok\"></form></td>
+	<td>". _("Redirection 2: ") ."</td>
+	<td><input type=\"text\" name=\"redirect2\" value=\"".$mailbox["data"]["redirect2"]."\"></td>
+</tr><tr>
+	<td></td><td>". drawSubmitButton( _("Ok") ) ."</form></td>
 </tr></table><br><br>";
 
-
-	if($mailbox["data"]["iwall_protect"] == "yes"){
+	if($mailbox["data"]["spam_mailbox_enable"] == "yes"){
+		$spambox_yes_checked = " checked ";
+		$spambox_no_checked = " ";
+	}else{
+		$spambox_yes_checked = " ";
+		$spambox_no_checked = " checked ";
 	}
 
+	$right .= "<h3>Anti-SPAM control</h3>
+<table cellpadding=\"0\" cellspacing=\"0\">
+<tr>
+	<td align=\"right\">Deliver spam to spambox:</td><td>".$form_start."<input type=\"hidden\" name=\"action\" value=\"dtcemail_spambox\">
+<input type=\"radio\" name=\"spam_mailbox_enable\" value=\"yes\" $spambox_yes_checked>"._("Yes")."<input type=\"radio\" name=\"spam_mailbox_enable\" value=\"no\" $spambox_no_checked>"._("No")."</td>
+</tr><tr>
+	<td align=\"right\">SPAM box name:</td><td><input type=\"text\" name=\"spam_mailbox\" value=\"".$mailbox["data"]["spam_mailbox"]."\"></td>
+</tr><tr>
+	<td></td><td>". drawSubmitButton( _("Ok") ) ."</form></td></tr></table>";
+	// Output the form
 	$out = "<table width=\"100%\" heigh=\"1\">
 <tr>
-	<td width=\"50%\">".skin("frame",$change_pass_form,"")."</td>
-	<td>".skin("frame",$redirect_form,"")."</td>
+	<td width=\"50%\" valign=\"top\">".$left."</td>
+	<td width=\"4\" background=\"gfx/skin/frame/border_2.gif\"></td>
+	<td valign=\"top\">".$right."</td>
 </tr>
 </table>
 ";
@@ -285,85 +289,71 @@ function drawAdminTools_emailPanel($mailbox){
 	global $conf_skin;
 	global $addrlink;
 
-	global $txt_mail_edit;
-	global $lang;
-
 	global $adm_email_login;
 	global $adm_email_pass;
 
-	global $txt_user_menu_email;
-	global $txt_user_menu_fetchmail;
-	global $txt_user_menu_antispam;
-	global $txt_user_menu_quarantine;
-	global $txt_logout;
-
 	$user_menu[] = array(
-		"text" => $txt_user_menu_email[$lang],
+		"text" => _("My e-mail") ,
+		"icon" => "box_wnb_nb_picto-mailboxes.gif",
 		"type" => "link",
 		"link" => "My Email");
 	$user_menu[] = array(
-		"text" => $txt_user_menu_fetchmail[$lang],
+		"text" => _("Fetchmail") ,
+		"icon" => "box_wnb_nb_picto-mailinglists.gif",
 		"type" => "link",
 		"link" => "fetchmail");
-	$user_menu[] = array(
-		"text" => $txt_user_menu_antispam[$lang],
-		"type" => "link",
-		"link" => "antispam");
-	$user_menu[] = array(
-		"text" => $txt_user_menu_quarantine[$lang],
-		"type" => "link",
-		"link" => "quarantine");
-
-	$logout = "<a href=\"".$_SERVER["PHP_SELF"]."?action=logout\">".$txt_logout[$lang]."</a>";
 
+	$logout = "<a href=\"".$_SERVER["PHP_SELF"]."?action=logout\">". _("Logout") ."</a>";
 	$mymenu = makeTreeMenu($user_menu,$addrlink,"".$_SERVER["PHP_SELF"]."?adm_email_login=$adm_email_login&adm_email_pass=$adm_email_pass","addrlink");
-	$left_menu = skin($conf_skin,"<br>".$mymenu."<center>$logout</center>",$adm_email_login);
 
-	$left_menu = "<table width=\"1\" height=\"100%\"><tr>
-		<td width=\"1\" height=\"1\">$left_menu</td>
+	switch($addrlink){
+	case "My Email":
+		$title = _("Mailbox configuration: ") ;
+		$panel = drawAdminTools_emailAccount($mailbox);
+		break;
+	case "antispam":
+		$title = _("Protect your mailbox with efficient tools:") ;
+		$panel = drawAntispamRules($mailbox);
+		break;
+	case "fetchmail":
+		$title = _("Your list of imported mail") ;
+		$panel = drawImportedMail($mailbox);
+		break;
+	case "quarantine":
+		$title = _("Those mail are in quarantine, and were not delivered to your pop account:") ;
+		$panel = drawQuarantine($mailbox);
+		break;
+	default:
+		$title = _("Welcom to the email panel!");
+		$panel = _("Login successfull. Please select a menu entry on the left...");
+		break;
+	}
+
+	if(function_exists("layoutEmailPanel")){
+		$content = layoutEmailPanel($adm_email_login,"<br>".$mymenu."<center>$logout</center>",$title,$panel);
+	}else{
+		$mymenu_skin = skin($conf_skin,"<br>".$mymenu."<center>$logout</center>",$adm_email_login);
+		$left = "<table width=\"1\" height=\"100%\"><tr>
+		<td width=\"1\" height=\"1\">$mymenu_skin</td>
 </tr><tr>
 		<td height=\"100%\">&nbsp;</td>
 </tr></table>";
 
-	switch($addrlink){
-	case "My Email":
-		$title = $txt_mail_edit[$lang];
-		$panel = drawAdminTools_emailAccount($mailbox);
-		break;
-	case "fetchmail":
-		$title = "Your list of imported mail";
-		$panel = drawImportedMail($mailbox);
-		break;
-	case "antispam":
-		$title = "Protect your mailbox with efficient tools:";
-		$panel = drawAntispamRules($mailbox);
-		break;
-	case "quarantine":
-		$title = "Those mail are in quarantine, and were not delivered to your pop account:";
-		$panel = drawQuarantine($mailbox);
-		break;
-	default:
-		$title = "Welcom to the email panel!";
-		$panel = "Login successfull. Please select a menu entry on the left...";
-		break;
-	}
+		$right = skin($conf_skin,$panel,$title);
 
-	$right = skin($conf_skin,$panel,$title);
-
-	$right = "<table width=\"100%\" height=\"100%\"><tr>
+		$right = "<table width=\"100%\" height=\"100%\"><tr>
 		<td width=\"100%\" height=\"100%\">$right</td>
 </tr><tr>
 	<td height=\"1\">&nbsp;</td>
 </tr></table>";
 
-	$content = "<table width=\"100%\" height=\"100%\"><tr>
-		<td width=\"1\"  height=\"100%\">$left_menu</td>
+		$content = "<table width=\"100%\" height=\"100%\"><tr>
+		<td width=\"1\"  height=\"100%\">$left</td>
 		<td width=\"100%\" height=\"100%\">$right</td>
 </tr></table>";
-
+	}
 	return $content;
-
-	return drawAdminTools_emailAccount($mailbox);
+//	return drawAdminTools_emailAccount($mailbox);
 }
 
 /////////////////////////////////////////
@@ -412,7 +402,7 @@ function emailAccountsCreateCallback ($id){
 	global $adm_login;
 	global $edit_domain;
 	global $cyrus_used;
-
+	global $pro_mysql_mailaliasgroup_table;
 	global $CYRUS;
 
 	$q = "SELECT * FROM $pro_mysql_pop_table WHERE autoinc='$id';";
@@ -429,13 +419,21 @@ function emailAccountsCreateCallback ($id){
 	if($testnum_rows >= 1){
 		$q = "DELETE FROM $pro_mysql_pop_table WHERE autoinc='$id';";
 		$r = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
-		return "<font color=\"red\">Error: a mailing list already exists with this name!</font>";
+		return "<font color=\"red\">". _("Error: a mailing list already exists with this name!") ."</font>";
+	}
+	$test_query = "SELECT * FROM $pro_mysql_mailaliasgroup_table WHERE id='".$a["id"]."' AND domain_parent='$edit_domain'";
+	$test_result = mysql_query ($test_query) or die("Cannot execute query \"$test_query\" line ".__LINE__." file ".__FILE__. " sql said ".mysql_error());
+	$testnum_rows = mysql_num_rows($test_result);
+	if($testnum_rows >= 1){
+		$q = "DELETE FROM $pro_mysql_pop_table WHERE autoinc='$id';";
+		$r = mysql_query($q) or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
+		return "<font color=\"red\">". _("Error: Email group alias already exists with this name!") ."</font><br />";
 	}
 	$crypted_pass = crypt($a["passwd"], dtc_makesalt());
 	writeDotQmailFile($a["id"],$a["mbox_host"]);
 	$admin_path = getAdminPath($adm_login);
 	$box_path = "$admin_path/$edit_domain/Mailboxs/".$a["id"];
-	$q = "UPDATE $pro_mysql_pop_table SET crypt='$crypted_pass',home='$box_path',uid='$conf_dtc_system_uid',gid='$conf_dtc_system_gid',fullemail='".$a["id"].'@'.$a["mbox_host"]."',quota_couriermaildrop=CONCAT(quota_size,'S,',quota_files,'C') WHERE autoinc='$id';";
+	$q = "UPDATE $pro_mysql_pop_table SET crypt='$crypted_pass',home='$box_path',uid='$conf_dtc_system_uid',gid='$conf_dtc_system_gid',fullemail='".$a["id"].'@'.$a["mbox_host"]."',quota_couriermaildrop=CONCAT(1024000*quota_size,'S,',quota_files,'C') WHERE autoinc='$id';";
 	$r2 = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
 	triggerMXListUpdate();
 	if ($cyrus_used){
@@ -466,7 +464,7 @@ function emailAccountsEditCallback ($id){
 	$a = mysql_fetch_array($r);
 
 	$crypted_pass = crypt($a["passwd"], dtc_makesalt());
-	$q = "UPDATE $pro_mysql_pop_table SET crypt='$crypted_pass',quota_couriermaildrop=CONCAT(quota_size,'S,',quota_files,'C') WHERE autoinc='$id';";
+	$q = "UPDATE $pro_mysql_pop_table SET crypt='$crypted_pass',quota_couriermaildrop=CONCAT(1024000*quota_size,'S,',quota_files,'C') WHERE autoinc='$id';";
 	$r = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
 
 	writeDotQmailFile($a["id"],$a["mbox_host"]);
@@ -512,35 +510,12 @@ function emailAccountsDeleteCallback ($id){
 	return "";
 }
 function drawAdminTools_Emails($domain){
-
 	global $adm_login;
 	global $adm_pass;
 	global $edit_domain;
 	global $edit_mailbox;
 	global $addrlink;
 
-	global $lang;
-	global $txt_login_login;
-	global $txt_login_pass;
-	global $txt_mail_liste_of_your_box;
-	global $txt_mail_new_mailbox;
-	global $txt_mail_redirection1;
-	global $txt_mail_redirection2;
-	global $txt_mail_spam_mailbox_enable;
-	global $txt_mail_spam_mailbox;
-	global $txt_mail_deliver_localy;
-	global $txt_mail_edit;
-	global $txt_mail_new_mailbox_link;
-	global $txt_number_of_active_mailbox;
-	global $txt_maximum_mailbox_reach;
-	global $txt_mail_catch_no;
-	global $txt_mail_catch_all_deliver;
-	global $txt_mail_quota;
-	global $txt_mail_quota_files;
-	global $txt_used_quota;
-	global $txt_mail_check_to_send_bounce_msg;
-	global $txt_mail_bounce_msg_content;
-
 	global $cyrus_used;
 	global $cyrus_default_quota;
 	global $CYRUS;
@@ -552,44 +527,51 @@ function drawAdminTools_Emails($domain){
 
 	$out = "";
 	$dsc = array(
-		"title" => $txt_mail_liste_of_your_box[$lang],
-		"new_item_title" => $txt_mail_new_mailbox[$lang],
-		"new_item_link" => $txt_mail_new_mailbox[$lang],
-		"edit_item_title" => $txt_mail_edit[$lang],
+		"title" => _("List of your mailboxes:") ,
+		"new_item_title" => _("New mailbox") ,
+		"new_item_link" => _("new mailbox") ,
+		"edit_item_title" => _("Mailbox configuration:") ,
 		"table_name" => $pro_mysql_pop_table,
 		"action" => "pop_access_editor",
 		"forward" => array("adm_login","adm_pass","addrlink"),
 		"id_fld" => "autoinc",
 		"list_fld_show" => "id",
 		"max_item" => $domain["max_email"],
-		"num_item_txt" => $txt_number_of_active_mailbox[$lang],
+		"num_item_txt" => _("Number of active mailboxes:") ,
 		"create_item_callback" => "emailAccountsCreateCallback",
 		"delete_item_callback" => "emailAccountsDeleteCallback",
 		"edit_item_callback" => "emailAccountsEditCallback",
 		"where_list" => array(
 			"mbox_host" => $domain["name"]),
+		"check_unique" => array( "id" ),
+		"check_unique_msg" => _("There is already a mailbox by that name") ,
+		"order_by" => "id",
 		"cols" => array(
 			"autoinc" => array(
 				"type" => "id",
 				"display" => "no",
-				"legend" => $txt_login_login[$lang]),
+				"legend" => _("Login:") ),
 			"id" => array(
 				"type" => "text",
 				"disable_edit" => "yes",
+				"check" => "dtc_login_or_email",
 				"happen" => "@".$domain["name"],
-				"legend" => $txt_login_login[$lang]),
+				"legend" => _("Login:") ),
+			"memo" => array (
+				"type" => "text",
+				"legend" => _("Name:") ),
 			"passwd" => array(
 				"type" => "password",
 				"check" => "dtc_pass",
-				"legend" => $txt_login_pass[$lang]),
+				"legend" => _("Password:") ),
 			"spam_mailbox_enable" => array(
 				"type" => "checkbox",
 				"values" => array( "yes","no"),
-				"legend" => $txt_mail_spam_mailbox_enable[$lang]),
+				"legend" => _("Enable SPAM filtering: ") ),
 			"spam_mailbox" => array(
 				"type" => "text",
 				"default" => "SPAM",
-				"legend" => $txt_mail_spam_mailbox[$lang]),
+				"legend" => _("SPAM mailbox destination: ") ),
 			)
 		);
 	if($cyrus_used) {
@@ -597,47 +579,50 @@ function drawAdminTools_Emails($domain){
 			"type" => "text",
 			"check" => "number",
 			"default" => "$cyrus_default_quota",
-			"legend" => $txt_mail_quota[$lang]);
+			"legend" => _("Mailbox quota: ") );
 		$dsc["cols"]["quota_used"] = array(
 			"type" => "readonly",
 			"hide_create" => "yes",
 			"callback" => "getCyrusUsedQuota",
-			"legend" => $txt_used_quota[$lang]);
+			"happen" => _("MBytes"),
+			"legend" => _("Used quota: ") );
 	} else {
 		$dsc["cols"]["quota_size"] = array(
 			"type" => "text",
 			"check" => "number",
-			"default" => "0",
-			"legend" => $txt_mail_quota[$lang]);
+			"default" => "10",
+			"happen" => _("MBytes"),
+			"legend" => _("Mailbox quota: ") );
 		$dsc["cols"]["quota_files"] = array(
 			"type" => "text",
 			"check" => "number",
-			"default" => "0",
-			"legend" => $txt_mail_quota_files[$lang]);
+			"default" => "1024",
+			"happen" => _("files"),
+			"legend" => _("Mailbox max files quota: ") );
 		$dsc["cols"]["redirect1"] = array(
 			"type" => "text",
 			"check" => "email",
 			"can_be_empty" => "yes",
 			"empty_makes_sql_null" => "yes",
-			"legend" => $txt_mail_redirection1[$lang]);
+			"legend" => _("Redirection 1: ") );
 		$dsc["cols"]["redirect2"] = array(
 			"type" => "text",
 			"check" => "email",
 			"can_be_empty" => "yes",
 			"empty_makes_sql_null" => "yes",
-			"legend" => $txt_mail_redirection2[$lang]);
+			"legend" => _("Redirection 1: ") );
 		$dsc["cols"]["localdeliver"] = array(
 			"type" => "checkbox",
 			"values" => array( "yes","no"),
-			"legend" => $txt_mail_deliver_localy[$lang]);
+			"legend" => _("Deliver messages locally in INBOX: ") );
 		$dsc["cols"]["vacation_flag"] = array(
 			"type" => "checkbox",
 			"values" => array( "yes","no"),
 			"default" => "no",
-			"legend" => $txt_mail_check_to_send_bounce_msg[$lang]);
+			"legend" => _("Check to send a bounce message (vacation): ") );
 		$dsc["cols"]["vacation_text"] = array(
 			"type" => "textarea",
-			"legend" => $txt_mail_bounce_msg_content[$lang],
+			"legend" => _("Bounce message content: ") ,
 			"cols" => "40",
 			"rows" => "7");
 	}
@@ -647,7 +632,7 @@ function drawAdminTools_Emails($domain){
         $q = "SELECT id FROM $pro_mysql_pop_table WHERE mbox_host='".$domain["name"]."';";
         $r = mysql_query($q)or die ("Cannot query $q line: ".__LINE__." file ".__FILE__." sql said:" .mysql_error());
         $n = mysql_num_rows($r);
-	$catch_popup = "<option value=\"no-mail-account\">".$txt_mail_catch_no[$lang]."</option>";
+	$catch_popup = "<option value=\"no-mail-account\">". _("No catch-all") ."</option>";
         for($i=0;$i<$n;$i++){
         	$a = mysql_fetch_array($r);
         	if($a["id"] == $domain["catchall_email"]){
@@ -657,7 +642,7 @@ function drawAdminTools_Emails($domain){
 		}
 		$catch_popup .= "<option value=\"".$a["id"]."\" $selected>".$a["id"]."</option>";
         }
-	$out .= "<b><u>".$txt_mail_catch_all_deliver[$lang].":</u></b><br>";
+	$out .= "<b><u>". _("Catch-all email set to deliver to") .":</u></b><br>";
 	$out .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
 	<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
 	<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
@@ -666,214 +651,10 @@ function drawAdminTools_Emails($domain){
 	Catchall: <input type=\"hidden\" name=\"action\" value=\"set_catchall_account\">
 	<select name=\"catchall_popup\">$catch_popup</select><input type=\"image\" src=\"gfx/stock_apply_20.png\">
 </form>";
-	
+
 	$out .= $list_items;
 	$out .= helpLink("PmWiki/Email-Accounts");
 	return $out;
-
-
-/*
-	if ($cyrus_used)
-	{
-		# login to cyradm
-		$cyr_conn = new cyradm;
-		$error=$cyr_conn -> imap_login();
-		if ($error!=0){
-			die ("imap_login Error $error");
-		}
-	}
-
-	if(isset($domain["emails"])){
-		$nbr_email = sizeof($domain["emails"]);
-		$emails = $domain["emails"];
-		$catchall_email = $domain["catchall_email"];
-	}
-	else	$nbr_email = 0;
-
-	$max_email = $domain["max_email"];
-	if($nbr_email >= $max_email){
-		$max_color = "color=\"#440000\"";
-	}else{
-		$max_color = "";
-	}
-	$nbrtxt = $txt_number_of_active_mailbox[$lang];
-	$txt = "<font size=\"-2\">$nbrtxt</font> <font size=\"-1\" $max_color>". $nbr_email ."</font> / <font size=\"-1\">" . $max_email . "</font><br><br>";
-
-	$txt .= "<font face=\"Arial, Verdana\"><font size=\"-1\"><b><u>".$txt_mail_catch_all_deliver[$lang].":</u><br>";
-	$catch_popup = "<option value=\"no-mail-account\">".$txt_mail_catch_no[$lang]."</option>";
-
-	$allmail_list = "";
-	$allmail_list .= "<font face=\"Arial, Verdana\"><font size=\"-1\"><b><u>".$txt_mail_liste_of_your_box[$lang]."</u><br>";
-	for($i=0;$i<$nbr_email;$i++){
-		$email = $emails[$i];
-		$id = $email["id"];
-		if(isset($_REQUEST["edit_mailbox"]) && $id == $_REQUEST["edit_mailbox"]){
-			$mailbox_name = $id;
-			$home = $email["home"];
-			$passwd = $email["passwd"];
-			$redir1 = $email["redirect1"];
-			$redir2 = $email["redirect2"];
-			$localdeliver = $email["localdeliver"];
-			$spam_mailbox_enable = $email["spam_mailbox_enable"];
-			if($localdeliver == "yes"){
-				$checkbox_state = " checked";
-				
-			}else{
-				$checkbox_state = "";
-			}
-			if ($spam_mailbox_enable  == "yes"){
-                                $spam_checkbox_state = " checked";
-
-                        }else{
-                                $spam_checkbox_state = "";
-                        }
-			$spam_mailbox = $email["spam_mailbox"];
-			if($email["vacation_flag"] == "yes"){
-				$checkbox_vacation_state = " checked ";
-			}else{
-				$checkbox_vacation_state = "";
-			}
-		}
-		if($i != 0){
-			$allmail_list .= " - ";
-		}
-		if($id == $catchall_email){
-			$catch_popup .= "<option value=\"$id\" selected>$id</option>";
-		}else{
-			$catch_popup .= "<option value=\"$id\">$id</option>";
-		}
-		$allmail_list .= "<a href=\"?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=$addrlink&edit_domain=$edit_domain&whatdoiedit=mails&edit_mailbox=$id\">$id</a>";
-	}
-
-	$txt .= "<form action=\"".$_SERVER["PHP_SELF"]."\">
-	<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
-	<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
-	<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
-	<input type=\"hidden\" name=\"edit_domain\" value=\"$edit_domain\">
-	<input type=\"hidden\" name=\"action\" value=\"set_catchall_account\">
-	<select name=\"catchall_popup\">$catch_popup</select><input type=\"submit\" value=\"Ok\">
-</form>";
-
-	$txt .= "<br><br>".$allmail_list;
-
-	if(!isset($_REQUEST["delemailaccount"]) && isset($_REQUEST["edit_mailbox"]) && $_REQUEST["edit_mailbox"] != ""){
-		$txt .= "<br><br><a href=\"?adm_login=$adm_login&adm_pass=$adm_pass&addrlink=$addrlink&edit_domain=$edit_domain&whatdoiedit=mails\">".$txt_mail_new_mailbox_link[$lang]."</a> ";
-		$txt .= "<br><br><u>".$txt_mail_edit[$lang]."</u><br><br>";
-
-		$txt .= "
-<table border=\"1\"><tr><td align=\"right\">
-<form name=\"emailfrm\" action=\"?\" methode=\"post\">
-	<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
-	<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
-	<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
-	<input type=\"hidden\" name=\"edit_domain\" value=\"$edit_domain\">
-	<input type=\"hidden\" name=\"whatdoiedit\" value=\"mails\">
-	<input type=\"hidden\" name=\"edit_mailbox\" value=\"".$_REQUEST["edit_mailbox"]."\">
-	".$txt_login_login[$lang]."</td><td><b>$mailbox_name</b>@$edit_domain
-</td><td align=\"right\">
-	".$txt_mail_redirection1[$lang]."</td><td><input type=\"text\" name=\"editmail_redirect1\" value=\"$redir1\">
-</td></tr><tr><td align=\"right\">";
-		$gen_button = autoGeneratePassButton("emailfrm","editmail_pass");
-		if ($conf_hide_password == "yes"){
-			$txt .= $txt_login_pass[$lang]."</td><td style=\"white-space: nowrap;\"><input type=\"password\" name=\"editmail_pass\" value=\"$passwd\">$gen_button";
-		} else {
-			$txt .= $txt_login_pass[$lang]."</td><td style=\"white-space: nowrap;\"><input type=\"text\" name=\"editmail_pass\" value=\"$passwd\">$gen_button";
-		}
-		$txt .= "
-</td><td align=\"right\">
-	".$txt_mail_redirection2[$lang]."</td><td><input type=\"text\" name=\"editmail_redirect2\" value=\"$redir2\">
-</td></tr><tr><td align=\"right\">";
-
-if ($cyrus_used)
-{
-	$cyrus_quota=$cyr_conn->getquota("user/" . $mailbox_name."@".$edit_domain);
-	$max_quota=$cyrus_quota['qmax'];
-	$used_quota=$cyrus_quota['used'];
-	$txt=$txt.$txt_mail_quota[$lang]."</td><td><input type=\"text\" name=\"cyrus_quota\" value=\"$max_quota\"> Kb</td><td align=\"right\">$txt_used_quota[$lang]: </td><td><b>$used_quota </b>Kb
-</td></tr>
-<tr><td align=\"right\">";
-}
-
-$txt=$txt.$txt_mail_deliver_localy[$lang]."</td><td><input type=\"checkbox\" name=\"editmail_deliver_localy\" value=\"yes\"$checkbox_state></td></tr>
-<tr>
-<td align=\"right\">".$txt_mail_spam_mailbox_enable[$lang]."</td><td><input type=\"checkbox\" name=\"editmail_spam_mailbox_enable\" value=\"yes\"$spam_checkbox_state></td>
-<td align=\"right\">".$txt_mail_spam_mailbox[$lang]."</td><td><input type=\"text\" name=\"editmail_spam_mailbox\" value=\"$spam_mailbox\"></td>
-</tr>";
-if (!$cyrus_used)
-{
-	$txt=$txt."<tr>
-	<td align=\"right\">Send vacation message:</td><td colspan=\"3\"><input type=\"checkbox\" name=\"editmail_vacation_flag\" value=\"yes\"$checkbox_vacation_state></td>
-	</tr><tr>
-	<td align=\"right\">Vacation message:</td><td colspan=\"3\"><textarea name=\"editmail_vacation_text\"></textarea></td>
-	</tr>";
-}
-else
-{
-	$txt=$txt."<input type=\"hidden\" name=\"editmail_vacation_text\" value=\"\">";
-}
-$txt=$txt."<tr><td>&nbsp;</td><td><input type=\"submit\" name=\"modifymailboxdata\" value=\"Ok\">&nbsp;
-<input type=\"submit\" name=\"delemailaccount\" value=\"Del\">
-</td></tr>
-</table>
-</form>
-";
-	}else{
-		$txt .= "<br><br><u>".$txt_mail_new_mailbox[$lang]."</u><br>";
-
-		if($nbr_email < $max_email){
-			if(isset($mailbox_name))	$mn = $mailbox_name;
-			else	$mn = "";
-			$txt .= "
-<form name=\"emailfrm\" action=\"".$_SERVER["PHP_SELF"]."\" methode=\"post\">
-<table border=\"1\"><tr><td align=\"right\">
-	<input type=\"hidden\" name=\"adm_login\" value=\"$adm_login\">
-	<input type=\"hidden\" name=\"adm_pass\" value=\"$adm_pass\">
-	<input type=\"hidden\" name=\"addrlink\" value=\"$addrlink\">
-	<input type=\"hidden\" name=\"edit_domain\" value=\"$edit_domain\">
-	<input type=\"hidden\" name=\"whatdoiedit\" value=\"mails\">
-	".$txt_login_login[$lang]."</td><td><input type=\"text\" name=\"newmail_login\" value=\"$mn\">
-</td><td align=\"right\">
-	".$txt_mail_redirection1[$lang]."</td><td><input type=\"text\" name=\"newmail_redirect1\" value=\"\">
-</td></tr><tr><td align=\"right\">";
-	if(isset($passwd)) $pd = $passwd;
-	else $pd = "";
-	if ($conf_hide_password == "yes"){
-		$txt .= $txt_login_pass[$lang]."</td><td style=\"white-space: nowrap;\"><input type=\"password\" name=\"newmail_pass\" value=\"$pd\">".autoGeneratePassButton("emailfrm","newmail_pass");
-	}else{
-		$txt .= $txt_login_pass[$lang]."</td><td style=\"white-space: nowrap;\"><input type=\"text\" name=\"newmail_pass\" value=\"$pd\">".autoGeneratePassButton("emailfrm","newmail_pass");
-	}
-$txt .= "
-</td><td align=\"right\">
-	".$txt_mail_redirection2[$lang]."</td><td><input type=\"text\" name=\"newmail_redirect2\" value=\"\">
-</td></tr>
-<tr><td align=\"right\">";
-
-if ($cyrus_used)
-{
-	$txt=$txt.$txt_mail_quota[$lang]."</td><td><input type=\"text\" name=\"cyrus_quota\" value=\"$cyrus_default_quota\">
-</td></tr>
-<tr><td align=\"right\">";
-}
-
-
-$txt=$txt.$txt_mail_deliver_localy[$lang]."</td><td><input type=\"checkbox\" name=\"newmail_deliver_localy\" value=\"yes\" checked></td></tr>
-<tr>
-<td align=\"right\">".$txt_mail_spam_mailbox_enable[$lang]."</td><td><input type=\"checkbox\" name=\"newmail_spam_mailbox_enable\" value=\"no\"></td>
-<td align=\"right\">".$txt_mail_spam_mailbox[$lang]."</td><td><input type=\"text\" name=\"newmail_spam_mailbox\" value=\"SPAM\"></td>
-</tr>
-<td></td>
-<td><input type=\"submit\" name=\"addnewmailtodomain\" value=\"Ok\">
-</td></tr>
-</table>
-</form>
-";
-		}else{
-			$txt .= $txt_maximum_mailbox_reach[$lang]."<br>";
-		}
-	}
-	$txt .= "</b></font></font>";
-	return $txt;
-*/
 }
 
 ?>
