@@ -34,6 +34,7 @@ function validateRenewal($renew_id){
 	global $submit_err;
 
 	global $conf_webmaster_email_addr;
+	global $conf_message_subject_header;
 
 	$q = "SELECT * FROM $pro_mysql_pending_renewal_table WHERE id='$renew_id';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
@@ -66,7 +67,8 @@ function validateRenewal($renew_id){
 			return false;
 		}
 		$vps_entry = mysql_fetch_array($r);
-		$date_expire = calculateExpirationDate($vps_entry["expire_date"],$product["period"]);
+		$old_expire = $vps_entry["expire_date"];
+		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_vps_table SET expire_date='$date_expire' WHERE id='".$renew_entry["renew_id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 		break;
@@ -80,7 +82,8 @@ function validateRenewal($renew_id){
 			return false;
 		}
 		$admin = mysql_fetch_array($r);
-		$date_expire = calculateExpirationDate($admin["expire"],$product["period"]);
+		$old_expire = $admin["expire"];
+		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_admin_table SET expire='$date_expire' WHERE adm_login='".$renew_entry["adm_login"]."'";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 		break;
@@ -102,6 +105,7 @@ function validateRenewal($renew_id){
 			return false;
 		}
 		$ssl_token = mysql_fetch_array($r);
+		$old_expire = date("Y-m-d");
 		$date_expire = calculateExpirationDate(date("Y-m-d"),$product["period"]);
 		$q = "UPDATE $pro_mysql_ssl_ips_table SET available='no',adm_login='".$admin["adm_login"]."',expire='$date_expire' WHERE id='".$ssl_token["id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
@@ -116,7 +120,8 @@ function validateRenewal($renew_id){
 			return false;
 		}
 		$dedicated_entry = mysql_fetch_array($r);
-		$date_expire = calculateExpirationDate($dedicated_entry["expire_date"],$product["period"]);
+		$old_expire = $dedicated_entry["expire_date"];
+		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_dedicated_table SET expire_date='$date_expire' WHERE id='".$renew_entry["renew_id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 		break;
@@ -139,7 +144,8 @@ function validateRenewal($renew_id){
 			return false;
 		}
 		$ssl_ip = mysql_fetch_array($r);
-		$date_expire = calculateExpirationDate($ssl_ip["expire"],$product["period"]);
+		$old_expire = $ssl_ip["expire"];
+		$date_expire = calculateExpirationDate($old_expire,$product["period"]);
 		$q = "UPDATE $pro_mysql_ssl_ips_table SET expire='$date_expire' WHERE  id='".$ssl_ip["id"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 		break;
@@ -148,18 +154,19 @@ function validateRenewal($renew_id){
 		break;
 	}
 
+	global $secpayconf_currency_letters;
 	$txt_renewal_approved = "
 
 A renewal have been paid! Here is the details of the renewal:
 
 login: ".$renew_entry["adm_login"]."
-Product: ".$product["name"]."(".$product["price_dollar"]." USD)
+Product: ".$product["name"]."(".$product["price_dollar"]." ".$secpayconf_currency_letters.")
 Date: ".$renew_entry["renew_date"]." ".$renew_entry["renew_time"]."
 
 ";
 
 	$headers = "From: ".$conf_webmaster_email_addr;
-	mail($conf_webmaster_email_addr,"[DTC] Renewal approved!",$txt_renewal_approved,$headers);
+	mail($conf_webmaster_email_addr,"$conf_message_subject_header Renewal approved!",$txt_renewal_approved,$headers);
 
 	$q = "SELECT id_client FROM $pro_mysql_admin_table WHERE adm_login='".$renew_entry["adm_login"]."'";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" line ".__LINE__." file ".__FILE__." sql said: ".mysql_error());
@@ -171,8 +178,8 @@ Date: ".$renew_entry["renew_date"]." ".$renew_entry["renew_time"]."
 	$cid = $admin["id_client"];
 
 	// Now add a command to the user so we keep tracks of payments
-	$q = "INSERT INTO $pro_mysql_completedorders_table (id,id_client,domain_name,quantity,date,product_id,payment_id,country_code)
-	VALUES ('','$cid','','1','".date("Y-m-d")."','".$product["id"]."','".$renew_entry["pay_id"]."','".$renew_entry["country_code"]."');";
+	$q = "INSERT INTO $pro_mysql_completedorders_table (id,id_client,domain_name,quantity,date,product_id,payment_id,country_code,last_expiry_date)
+	VALUES ('','$cid','','1','".date("Y-m-d")."','".$product["id"]."','".$renew_entry["pay_id"]."','".$renew_entry["country_code"]."','$old_expire');";
 	mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 
 	$q = "DELETE FROM $pro_mysql_pending_renewal_table WHERE id='$renew_id';";
@@ -192,6 +199,8 @@ function validateWaitingUser($waiting_login){
 	global $pro_mysql_completedorders_table;
 	global $pro_mysql_domain_table;
 
+	global $dtcshared_path;
+
 	global $txt_userwaiting_account_activated_subject;
 	global $txt_userwaiting_account_activated_text_header;
 
@@ -200,8 +209,22 @@ function validateWaitingUser($waiting_login){
 	global $conf_use_ssl;
 	global $conf_webmaster_email_addr;
 	global $conf_this_server_country_code;
+	global $conf_message_subject_header;
 	global $console;
 
+	//get affiliate cookie
+	if( isset($_COOKIE["affiliate"]) && isMailbox($affiliatename)){
+		$affiliatename = $_COOKIE["affiliate"];
+	}
+
+	if (isset($affiliatename)) {
+		//Step 1: validate that the affiliatename exists
+		$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='".mysql_real_escape_string($affiliatename)."';";
+		$r = mysql_query($q) or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		if (mysql_num_rows($r) != 1) { unset($affiliatename); }
+		// at this point, we should have an affiliatename
+	}
+
 	// Check if there is a user by that name
 	$q = "SELECT * FROM $pro_mysql_admin_table WHERE adm_login='$waiting_login';";
 	$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
@@ -260,18 +283,18 @@ disk_quota_mb,bw_quota_per_month_gb,special_note) VALUES ('','".$a["iscomp"]."',
         	$admtbl_added2 = ",'$expires','".$a2["id"]."'";
         }
 	$adm_query = "INSERT INTO $pro_mysql_admin_table
-(adm_login        ,adm_pass         ,path            ,id_client,bandwidth_per_month_mb,quota,nbrdb,max_email$admtbl_added1) VALUES
-('$waiting_login','".$a["reqadm_pass"]."','$newadmin_path','$cid','".$a2["bandwidth"]."','".$a2["quota_disk"]."','".$a2["nbr_database"]."','".$a2["nbr_email"]."'$admtbl_added2);";
+(adm_login        ,adm_pass         ,path            ,id_client,bandwidth_per_month_mb,quota,nbrdb,allow_add_domain,max_email$admtbl_added1) VALUES
+('$waiting_login','".$a["reqadm_pass"]."','$newadmin_path','$cid','".$a2["bandwidth"]."','".$a2["quota_disk"]."','".$a2["nbr_database"]."','".$a2["allow_add_domain"]."','".$a2["nbr_email"]."'$admtbl_added2);";
 	mysql_query($adm_query)or die("Cannot execute query \"$adm_query\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 
         if($a2["heb_type"] == "vps"){
-		$vps_xen_name = addVPSToUser($waiting_login,$a["vps_location"],$a2["id"]);
+		$vps_xen_name = addVPSToUser($waiting_login,$a["vps_location"],$a2["id"],$a["vps_os"]);
 		$soap_client = connectToVPSServer($a["vps_location"]);
 		if($soap_client == false){
 			echo "Could not connect to the VPS server for doing the setup: please contact the administrator!";
 		}else{
 			$image_type = "lvm";
-			if (isVPSNodeLVMEnabled($vps_node) == "no"){
+			if (isVPSNodeLVMEnabled($a["vps_location"]) == "no"){
                                 $image_type = "vbd";
                         }
 
@@ -301,93 +324,113 @@ disk_quota_mb,bw_quota_per_month_gb,special_note) VALUES ('','".$a["iscomp"]."',
 				}
 			}
 		}
-		$txt_welcome_message = "The Virtual Server hosting account you have ordered
-has been validated. It's currently setting-up your
-operating system. You can login in the control panel
-using the information following.
 
-Once the operating system will be setup, you will have
-to click on the control panel to bootup your VPS. Once
-it boots up, you need to login on the physical console
-using ssh (after you have setup your password).
-
-Once you are logged on the physica console of your VPS,
-login as root, and change the root password. Then, you
-can install ssh on it and finish the installation.
-
-Note that if you need our team to setup DTC control
-panel on your VPS, you need to get in touch with us.
-
-Here is your login information in the DTC control panel:";
+		// Read the (customizable) registration message to send
+		if(file_exists("/etc/dtc/registration_msg/vps_open.txt")){
+			$fname = "/etc/dtc/registration_msg/vps_open.txt";
+		}else{
+			$fname = "$dtcshared_path/registration_msg/vps_open.txt";
+		}
+		$fp = fopen($fname,"r");
+		$txt_welcome_message = fread($fp,filesize($fname));
+		fclose($fp);
 	}else if($a2["heb_type"] == "server"){
 		// As there is currently no dedicated server provision system, we just do this:
 		$country = $conf_this_server_country_code;
 		addDedicatedToUser($waiting_login,$a["domain_name"],$a2["id"]);
-		$txt_welcome_message = "The dedicated server you have ordered is now
-validated. Note that there is a delay when ordering a
-dedicated server with us. Please get in touch to know
-how long it can take to have it online.
 
-From now on, you can login to our control panel for doing
-the renewals of your contract. Here is the login information
-you will need:";
+		// Read the (customizable) registration message to send
+		if(file_exists("/etc/dtc/registration_msg/dedicated_open.txt")){
+			$fname = "/etc/dtc/registration_msg/dedicated_open.txt";
+		}else{
+			$fname = "$dtcshared_path/registration_msg/dedicated_open.txt";
+		}
+		$fp = fopen($fname,"r");
+		$txt_welcome_message = fread($fp,filesize($fname));
+		fclose($fp);
         }else{
         	$country = $conf_this_server_country_code;
 		addDomainToUser($waiting_login,$a["reqadm_pass"],$a["domain_name"]);
-		$txt_welcome_message = "The shared hosting account you have ordered is now
-ready to be used. Note that it can take up to 10 minutes
-until your domain name is setup on our DNS and apache
-server (a cron job runs each 10 minutes for new mail,
-domains and subdomains, but you don't need to wait
-for your ftp accounts).
 
-Note that your files should be uploaded in:
+		// Read the (customizable) registration message to send
+		if(file_exists("/etc/dtc/registration_msg/shared_open.txt")){
+			$fname = "/etc/dtc/registration_msg/shared_open.txt";
+		}else{
+			$fname = "$dtcshared_path/registration_msg/shared_open.txt";
+		}
+		$fp = fopen($fname,"r");
+		$txt_welcome_message = fread($fp,filesize($fname));
+		fclose($fp);
 
-/var/www/sites/YOU-USERNAME/your-domain.com/subdomains/www/html
-
-And when creating a new ftp account, you wont see the
-first part of the path, so it will be relative to:
-
-/var/www/sites/YOU-USERNAME
-
-You can login to the control
-panel using the following informations:";
 		$q = "UPDATE $pro_mysql_domain_table SET max_email='".$a2["nbr_email"]."',quota='".$a2["quota_disk"]."' WHERE name='".$a["domain_name"]."';";
 		$r = mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
         }
 
 	// Send a mail to user with how to login and use interface.
-	$txt_userwaiting_account_activated_subject = "GPLHost:>_ Account $waiting_login has been activated!";
+	$txt_userwaiting_account_activated_subject = "$conf_message_subject_header Account $waiting_login has been activated!";
+
+	// Manage the signature of all registration messages
+	if(file_exists("/etc/dtc/signature.txt")){
+		$fname = "/etc/dtc/signature.txt";
+	}else{
+		$fname = "/usr/local/www/dtc/etc/signature.txt";
+	}
+	if(file_exists($fname)){
+		$fp = fopen($fname,"r");
+		$signature = fread($fp,filesize($fname));
+		fclose($fp);
+	}else{
+		$signature = "";
+	}
+	$msg_2_send = str_replace("%%%SIGNATURE%%%",$signature,$txt_welcome_message);
+
+	// Manage the login info part of the message
 	if($conf_use_ssl == "yes"){
 		$surl = "s";
 	}else{
 		$surl = "";
 	}
-	$txt_userwaiting_account_activated_text_header = "DTC hosting account opened!
-
-Hello,
-
-This is a message sent automaticaly by the Domain
-Technologie Control panel robot.
-
-$txt_welcome_message
-
-URL: http$surl://$conf_administrative_site/dtc/
+	$dtc_login_info = "URL: http$surl://$conf_administrative_site/dtc/
 Login: $waiting_login
-Password: ".$a["reqadm_pass"]."
+Password: ".$a["reqadm_pass"];
+	$msg_2_send = str_replace("%%%DTC_LOGIN_INFO%%%",$dtc_login_info,$msg_2_send);
+
+	// Manage the header of the messages
+	if(file_exists("/etc/dtc/messages_header.txt")){
+		$fname = "/etc/dtc/messages_header.txt";
+	}else{
+		$fname = "/usr/local/www/dtc/etc/messages_header.txt";
+	}
+	if(file_exists($fname)){
+		$fp = fopen($fname,"r");
+		$head = fread($fp,filesize($fname));
+		fclose($fp);
+	}else{
+		$head = "";
+	}
+	$msg_2_send = $head."
+".$msg_2_send;
 
-GPLHost:>_ Open-source hosting worldwide.
-http://www.gplhost.com
-";
 	$headers = "From: ".$conf_webmaster_email_addr;
-	mail($a["email"],$txt_userwaiting_account_activated_subject,
-		$txt_userwaiting_account_activated_text_header,$headers);
+	mail($a["email"],$txt_userwaiting_account_activated_subject,$msg_2_send,$headers);
 
 	// Now add a command to the user so we keep tracks of payments
-	$q = "INSERT INTO $pro_mysql_completedorders_table (id,id_client,domain_name,quantity,date,product_id,payment_id,country_code)
-	VALUES ('','$cid','".$a["domain_name"]."','1','".date("Y-m-d")."','".$a["product_id"]."','".$a["paiement_id"]."','$country');";
+	$q = "INSERT INTO $pro_mysql_completedorders_table (id,id_client,domain_name,quantity,date,product_id,payment_id,country_code,last_expiry_date)
+	VALUES ('','$cid','".$a["domain_name"]."','1','".date("Y-m-d")."','".$a["product_id"]."','".$a["paiement_id"]."','$country','".date("Y-d-m")."');";
 	mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
 
+	if (isset($affiliatename)) {
+		// Step 2) retrieve the kickback from the products table
+		$kickback = $a2["affiliate_kickback"];
+		$orderid = mysql_insert_id();
+		if ($kickback) {
+			// Step 3) if a kickback exists, store it in the affiliate transaction table
+			$kickback = 1.0 + $kickback - 1.0; //cast to float.  I hate PHP.
+			$xxs = "INSERT INTO affiliate_payments (adm_login,order_id,kickback) VALUES('$affiliatename',$orderid,$kickback);";
+			mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
+		}
+	}
+
 	// Finaly delete the user from the userwaiting table
 	$q = "DELETE FROM $pro_mysql_new_admin_table WHERE reqadm_login='$waiting_login';";
 	mysql_query($q)or die("Cannot execute query \"$q\" ! line: ".__LINE__." file: ".__FILE__." sql said: ".mysql_error());
@@ -545,8 +588,8 @@ if($panel_type!="email"){
 	require("$dtcshared_path/inc/sql/dns.php");
 	require("$dtcshared_path/inc/sql/database.php");
 	require("$dtcshared_path/inc/sql/domain_info.php");
+	require("$dtcshared_path/inc/sql/domain_stats.php");
 	require("$dtcshared_path/inc/sql/subdomain.php");
-	require("$dtcshared_path/inc/sql/ftp.php");
 	require("$dtcshared_path/inc/sql/ssh.php");
 	require("$dtcshared_path/inc/sql/email.php");
 	require("$dtcshared_path/inc/sql/lists.php");
